@@ -1,6 +1,6 @@
-/* $Id: about.cpp,v 1.133 2005/06/27 02:54:46 Sirp Exp $ */
+/* $Id: about.cpp 8367 2005-09-23 07:42:41Z isaac $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -39,6 +39,8 @@ std::vector<std::string> get_text() {
 
 		"_" N_("+Developers"),
 		"-   Alfredo Beaumont (ziberpunk)",
+		"-   András Salamon (ott)",
+		"-   Bram Ridder (Morloth)",
 		"-   Cedric Duval",
 		"-   Cyril Bouthors (CyrilB)",
 		"-   Guillaume Melquiond (silene)",
@@ -50,7 +52,6 @@ std::vector<std::string> get_text() {
 		"-   J.R. Blain (Cowboy)",
 		"-   Kristoffer Erlandsson (erl)",
 		"-   Maksim Orlovich (SadEagle)",
-		"-   ott",
 		"-   Philippe Plantier (Ayin)",
 		"-   Yann Dirson",
 		"-   Zas",
@@ -60,6 +61,7 @@ std::vector<std::string> get_text() {
 		"-   Isaac Clerencia",
 
 		"_" N_("+Artwork and graphics designers"),
+		"-   Alex Jarocha-Ernst (Jormungandr)",
 		"-   Andrew James Patterson (Kamahawk)",
 		"-   antwerp",
 		"-   Christophe Anjard",
@@ -68,6 +70,7 @@ std::vector<std::string> get_text() {
 		"-   Gareth Miller (Gafgarion)",
 		"-   Hogne Håskjold (frame)",
 		"-   James Barton (Sangel)",
+		"-   James Woo (Pickslide)",
 		"-   Jason Lutes",
 		"-   Jimmy Olsson (Azlan)",
 		"-   Johanna Manninen (lohari)",
@@ -101,9 +104,9 @@ std::vector<std::string> get_text() {
 		"-   Justin Zaun (jzaun)",
 
 		"_" N_("+Multiplayer Maps"),
+		"-   Mike Quinones (Doc Paterson)",
 		"-   Peter Groen (pg)",
 		"-   Tom Chance (telex4)",
-		"-   Mike Quinones (Doc Paterson)",
 
 		"_" N_("+Packagers"),
 		"-   Cyril Bouthors (CyrilB)",
@@ -116,8 +119,10 @@ std::vector<std::string> get_text() {
 		"-   Mark Michelsen (skovbaer)",
 
 		"_" N_("+Miscellaneous"),
+		"-   Bartek Waresiak (Dragonking)",
 		"-   Francesco Gigli (Jaramir)",
 		"-   Jordà Polo (ettin)",
+		"-   Richard S. (Noy)",
 		"-   Ruben Philipp Wickenhäuser (The Very Uhu)",
 
 		"_" N_("+Internationalization Managers"),
@@ -128,8 +133,8 @@ std::vector<std::string> get_text() {
 		"-   Susanna Björverud (sanna)",
 
 		"_" N_("+Afrikaans Translation"),
+		"-   András Salamon (ott)",
 		"-   Nico Oliver",
-		"-   ott",
 
 		"_" N_("+Basque Translation"),
 		"-   Alfredo Beaumont (ziberpunk)",
@@ -138,12 +143,15 @@ std::vector<std::string> get_text() {
 
 		"_" N_("+Bulgarian Translation"),
 		"-   Anton Tsigularov (Atilla)",
+		"-   Georgi Dimitrov (oblak)",
 
 		"_" N_("+Catalan Translation"),
 		"-   Carles Company (brrr)",
 		"-   Dan Rosàs Garcia (focks)",
+		"-   Daniel López (Azazelo)",
 		"-   Jonatan Alamà (tin)",
 		"-   Jordà Polo (ettin)",
+		"-   Jose Gordillo (kilder)",
 		"-   Mark Recasens",
 		"-   Pau Rul·lan Ferragut",
 
@@ -152,13 +160,20 @@ std::vector<std::string> get_text() {
 
 		"_" N_("+Czech Translation"),
 		"-   David Nečas (Yeti)",
+		"-   Lukáš Faltýnek",
+		"-   Martin Šín",
 		"-   Mintaka",
 		"-   Petr Kopač (Ferda)",
 		"-   Petr Kovár (Juans)",
+		"-   Rudolf Orság",
 		"-   Sofronius",
+		"-   Vít Komárek",
 		"-   Vít Krčál",
 
 		"_" N_("+Danish Translation"),
+		"-   Anders K. Madsen (madsen)",
+		"-   Bjarke Sørensen (basher)",
+		"-   Jesper Fuglsang Wolff (ulven)",
 		"-   Mark Michelsen (skovbaer)",
 		"-   Mathias Bundgaard Svensson (freaken)",
 
@@ -167,29 +182,37 @@ std::vector<std::string> get_text() {
 		"-   Lala",
 		"-   Maarten Albrecht",
 		"-   Pieter Vermeylen (Onne)",
+                "-   Roel Thijs (Roel)",
 		"-   Tobe Deprez",
 
 		"_" N_("+English (GB) Translation"),
-		"-   ott",
+		"-   András Salamon (ott)",
 
 		"_" N_("+Estonian Translation"),
 		"-   Mart Tõnso",
 
 		"_" N_("+Finnish Translation"),
 		"-   Ankka",
+		"-   kko",
 		"-   Matias Parmala",
 		"-   paxed",
 
 		"_" N_("+French Translation"),
+		"-   Aurélien Brevers (Breversa)",
 		"-   Benoit Astruc",
 		"-   Cédric Duval",
 		"-   DaringTremayne",
+		"-   François Orieux",
 		"-   Guillaume Duwelz-Rebert",
 		"-   Guillaume Massart (Piou2fois)",
 		"-   Guillaume Melquiond (silene)",
+		"-   Jean Privat (Tout)",
 		"-   Jean-Luc Richard (Le Gnome)",
+		"-   Jérémy Rosen (Boucman)",
+		"-   Julien Moncel",
+		"-   Julien Tailleur",
+		"-   Nicolas Boudin (Blurgk)",
 		"-   Philippe Plantier (Ayin)",
-		"-   Tout",
 		"-   Yann Dirson",
 		"-   Zas",
 
@@ -198,6 +221,7 @@ std::vector<std::string> get_text() {
 		"-   Boris Stumm (quijote_)",
 		"-   Christoph Berg (chrber)",
 		"-   Gerfried Fuchs (Alfie)",
+		"-   Jan Greve (Jan)",
 		"-   Jan Heiner Laberenz (jan-heiner)",
 		"-   Kai Ensenbach (Pingu)",
 		"-   Nils Kneuper (Ivanovic)",
@@ -207,16 +231,20 @@ std::vector<std::string> get_text() {
 		"_" N_("+Greek Translation"),
 		"-   Katerina Sykioti",
 		"-   Konstantinos Karasavvas",
+                "-   Spiros, Giorgis",
+                "-   Alexander Alexiou (Santi)",
 
 		"_" N_("+Hungarian Translation"),
 		"-   adson",
+		"-   Beer (Eddi)",
 		"-   dentro",
+		"-   Gilluin",
 		"-   Kékkői László (BlackEvil)",
 		"-   Kertész Csaba",
 		"-   Khiraly",
 		"-   Kovács Dániel",
 		"-   krix",
-		"-   ott",
+		"-   Salamon András (ott)",
 		"-   Széll Tamás (TomJoad)",
 
 		"_" N_("+Italian Translation"),
@@ -229,8 +257,8 @@ std::vector<std::string> get_text() {
 		"-   RokStar",
 
 		"_" N_("+Japanese Translation"),
-		"-   Naoki Iimura",
-		"-   Nobuhito Okada",
+		"-   いいむらなおき (amatubu) - Naoki Iimura",
+		"-   岡田信人 - Nobuhito Okada",
 		"-   Yuji Matsumoto",
 
 		"_" N_("+Latin Translation"),
@@ -259,10 +287,12 @@ std::vector<std::string> get_text() {
 		"-   Michel Loos",
 		"-   Renato Cunha",
 		"-   Sérgio de Miranda Costa",
+		"-   Tiago Souza (Salvador)",
 
 		"_" N_("+Russian Translation"),
 		"-   Alexandr Menovchicov",
 		"-   Azamat Hackimov",
+		"-   Ilya Kaznacheev",
 		"-   Roman Tuchin (Sankt)",
 
 		"_" N_("+Serbian Translation"),
@@ -275,21 +305,25 @@ std::vector<std::string> get_text() {
 		"-   Jaka Kranjc (lynx)",
 
 		"_" N_("+Spanish Translation"),
-		"-   David Martínez",
+		"-   David Martínez Moreno",
 		"-   Flamma",
 		"-   Franciso Muñoz (fmunoz)",
 		"-   Gabriel Rodríguez (Chewie)",
+		"-   Iván Herrero (navitux)",
 		"-   Jose Gordillo (kilder)",
 		"-   Jose Manuel Gomez (joseg)",
 
 		"_" N_("+Swedish Translation"),
 		"-   Alexander Kjäll (capitol)",
+		"-   Leo Danielson (Lugo Moll)",
 		"-   Stefan Bergström (tephlon)",
 		"-   Susanna Björverud (sanna)",
 		"-   wint3r",
 
 		"_" N_("+Turkish Translation"),
+		"-   Enes Akın (yekialem)",
 		"-   İhsan Akın",
+		"-   Kosif",
 		"-   Selim Farsakoğlu",
 
 		"_" N_("+Contributors"),
