@@ -1,6 +1,6 @@
-/* $Id: actions.cpp,v 1.230 2005/06/12 21:39:49 Sirp Exp $ */
+/* $Id: actions.cpp 8311 2005-09-19 06:25:36Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -86,6 +86,23 @@ namespace victory_conditions
 	}
 }
 
+bool can_recruit_on(const gamemap& map, const gamemap::location& leader, const gamemap::location loc)
+{
+	if(!map.on_board(loc))
+		return false;
+
+	if(!map.is_castle(loc))
+		return false;
+
+	castle_cost_calculator calc(map);
+	const paths::route& rt = a_star_search(leader, loc, 100.0, &calc, map.x(), map.y());
+
+	if(rt.steps.empty())
+		return false;
+
+	return true;
+}
+
 std::string recruit_unit(const gamemap& map, int side,
        std::map<gamemap::location,unit>& units, unit& new_unit,
        gamemap::location& recruit_location, display* disp, bool need_castle, bool full_movement)
@@ -96,9 +113,9 @@ std::string recruit_unit(const gamemap& map, int side,
 	typedef std::map<gamemap::location,unit> units_map;
 
 	//find the unit that can recruit
-	units_map::const_iterator u = units.end();
+	units_map::const_iterator u = units.begin();
 
-	for(u = units.begin(); u != units.end(); ++u) {
+	for(; u != units.end(); ++u) {
 		if(u->second.can_recruit() && u->second.side() == side) {
 			break;
 		}
@@ -115,11 +132,10 @@ std::string recruit_unit(const gamemap& map, int side,
 		return _("You must have your leader on a keep to recruit or recall units.");
 	}
 
-	if(need_castle && map.on_board(recruit_location)) {
-		castle_cost_calculator calc(map);
-		const paths::route& rt = a_star_search(u->first, recruit_location, 100.0, &calc, map.x(), map.y());
-		if(rt.steps.empty() || units.find(recruit_location) != units.end() ||
-		   !map.is_castle(recruit_location)) {
+	if(need_castle) {
+		if (units.find(recruit_location) != units.end() ||
+			!can_recruit_on(map, u->first, recruit_location)) {
+
 			recruit_location = gamemap::location();
 		}
 	}
@@ -141,6 +157,7 @@ std::string recruit_unit(const gamemap& map, int side,
 		new_unit.set_movement(0);
 		new_unit.set_attacked();
 	}
+	new_unit.heal_all();
 
 	const bool show = disp != NULL && !disp->turbo() &&
 	                  !disp->fogged(recruit_location.x,recruit_location.y);
@@ -370,13 +387,13 @@ battle_stats evaluate_battle_stats(const gamemap& map,
 	res.attacker_slows = res.attacker_special == slow_string;
 
 	if (strings) {
-		strings->attack_name = egettext(attack.name().c_str());
+		strings->attack_name = attack.name();
 		strings->attack_type = egettext(attack.type().c_str());
 		strings->attack_special = egettext(res.attacker_special.c_str());
 		strings->attack_icon = attack.icon();
 
 		//don't show backstabbing unless it's actually happening
-		if(attack.special() == backstab_string && !backstab)
+		if(res.attacker_special == backstab_string && !backstab)
 			strings->attack_special = "";
 
 		strings->range = gettext(attack.range() == attack_type::SHORT_RANGE ? N_("melee") : N_("ranged"));
@@ -408,6 +425,8 @@ battle_stats evaluate_battle_stats(const gamemap& map,
 	static const std::string EMPTY_COLUMN = std::string(1, COLUMN_SEPARATOR) + ' ' + COLUMN_SEPARATOR;
 
 	res.damage_attacker_takes = 0;
+	res.amount_attacker_drains = 0;
+	res.amount_defender_drains = 0;
 	if (counterattack) {
 		const attack_type& defend = defender_attacks[defend_with];
 		res.defender_special = defend.special();
@@ -490,7 +509,7 @@ battle_stats evaluate_battle_stats(const gamemap& map,
 		res.ndefends = defend.num_attacks();
 
 		if (strings) {
-			strings->defend_name = egettext(defend.name().c_str());
+			strings->defend_name = defend.name();
 			strings->defend_type = egettext(defend.type().c_str());
 			strings->defend_special = egettext(res.defender_special.c_str());
 			strings->defend_icon = defend.icon();
@@ -500,8 +519,6 @@ battle_stats evaluate_battle_stats(const gamemap& map,
 		//the defender will drain for half the damage it does
 		if (res.defender_special == drain_string && !a->second.type().not_living()) {
 			res.amount_defender_drains = res.damage_attacker_takes/2;
-		} else {
-			res.amount_defender_drains = 0;
 		}
 
 		res.defender_plague = !a->second.type().not_living() &&
@@ -598,7 +615,7 @@ battle_stats evaluate_battle_stats(const gamemap& map,
 		if(steadfast && resistance_modifier < 100) {
 			str_resist << ' ' << _(" (+steadfast)");
 		}
-		
+
 		str_resist << EMPTY_COLUMN
 		           << (resist > 0 ? "+" : "") << resist << '%';
 		strings->attack_calculations.push_back(str_resist.str());
@@ -621,10 +638,8 @@ battle_stats evaluate_battle_stats(const gamemap& map,
 
 	//if the attacker drains, and the defender is a living creature, then
 	//the attacker will drain for half the damage it does
-	if(attack.special() == drain_string && !d->second.type().not_living()) {
+	if(res.attacker_special == drain_string && !d->second.type().not_living()) {
 		res.amount_attacker_drains = res.damage_defender_takes/2;
-	} else {
-		res.amount_attacker_drains = 0;
 	}
 
 	static const std::string slowed_string("slowed");
@@ -1091,11 +1106,11 @@ int village_owner(const gamemap::location& loc, const std::vector<team>& teams)
 	return -1;
 }
 
-void get_village(const gamemap::location& loc, std::vector<team>& teams,
+bool get_village(const gamemap::location& loc, std::vector<team>& teams,
                  size_t team_num, const unit_map& units)
 {
 	if(team_num < teams.size() && teams[team_num].owns_village(loc)) {
-		return;
+		return false;
 	}
 
 	const bool has_leader = find_leader(units,int(team_num+1)) != units.end();
@@ -1110,12 +1125,14 @@ void get_village(const gamemap::location& loc, std::vector<team>& teams,
 	}
 
 	if(team_num >= teams.size()) {
-		return;
+		return false;
 	}
 
 	if(has_leader) {
-		teams[team_num].get_village(loc);
+		return teams[team_num].get_village(loc);
 	}
+
+	return false;
 }
 
 unit_map::iterator find_leader(unit_map& units, int side)
@@ -1636,12 +1653,12 @@ bool clear_shroud_loc(const gamemap& map, team& tm,
 //seen_units will return new units that have been seen by this unit
 //if known_units is NULL, seen_units can be NULL and will not be changed
 bool clear_shroud_unit(const gamemap& map,
-		                 const gamestatus& status,
-							  const game_data& gamedata,
-                       const unit_map& units, const gamemap::location& loc,
-                       std::vector<team>& teams, int team,
-					   const std::set<gamemap::location>* known_units,
-					   std::set<gamemap::location>* seen_units)
+		const gamestatus& status,
+		const game_data& gamedata,
+		const unit_map& units, const gamemap::location& loc,
+		std::vector<team>& teams, int team,
+		const std::set<gamemap::location>* known_units,
+		std::set<gamemap::location>* seen_units)
 {
 	std::vector<gamemap::location> cleared_locations;
 
@@ -1671,7 +1688,7 @@ bool clear_shroud_unit(const gamemap& map,
 		  || teams[team].is_enemy(sighted->second.side()) == false)) {
 			if(seen_units == NULL || known_units == NULL) {
 				static const std::string sighted("sighted");
-				game_events::fire(sighted,*it,loc);
+				game_events::raise(sighted,*it,loc);
 			} else if(known_units->count(*it) == 0) {
 				seen_units->insert(*it);
 			}
@@ -1684,45 +1701,39 @@ bool clear_shroud_unit(const gamemap& map,
 }
 
 void recalculate_fog(const gamemap& map, const gamestatus& status,
-		const game_data& gamedata, const unit_map& units,
+		const game_data& gamedata, unit_map& units,
 		std::vector<team>& teams, int team) {
 
 	teams[team].refog();
 
-	for(unit_map::const_iterator i = units.begin(); i != units.end(); ++i) {
+	for(unit_map::iterator i = units.begin(); i != units.end(); ++i) {
 		if(i->second.side() == team+1) {
-
-			//we're not really going to mutate the unit, just temporarily
-			//set its moves to maximum, but then switch them back
-			unit& mutable_unit = const_cast<unit&>(i->second);
-			const unit_movement_resetter move_resetter(mutable_unit);
+			const unit_movement_resetter move_resetter(i->second);
 
 			clear_shroud_unit(map,status,gamedata,units,i->first,teams,team,NULL,NULL);
 		}
 	}
+	game_events::pump();
 }
 
 bool clear_shroud(display& disp, const gamestatus& status,
-		            const gamemap& map, const game_data& gamedata,
-                  const unit_map& units, std::vector<team>& teams, int team)
+		const gamemap& map, const game_data& gamedata,
+                  unit_map& units, std::vector<team>& teams, int team)
 {
 	if(teams[team].uses_shroud() == false && teams[team].uses_fog() == false)
 		return false;
 
 	bool result = false;
 
-	unit_map::const_iterator i;
+	unit_map::iterator i;
 	for(i = units.begin(); i != units.end(); ++i) {
 		if(i->second.side() == team+1) {
-
-			//we're not really going to mutate the unit, just temporarily
-			//set its moves to maximum, but then switch them back
-			unit& mutable_unit = const_cast<unit&>(i->second);
-			const unit_movement_resetter move_resetter(mutable_unit);
+			const unit_movement_resetter move_resetter(i->second);
 
 			result |= clear_shroud_unit(map,status,gamedata,units,i->first,teams,team,NULL,NULL);
 		}
 	}
+	game_events::pump();
 
 	recalculate_fog(map,status,gamedata,units,teams,team);
 
@@ -1889,21 +1900,25 @@ size_t move_unit(display* disp, const game_data& gamedata,
 		disp->invalidate(steps.back());
 	}
 
-	int orig_village_owner = -1;
-	if(map.is_village(steps.back())) {
-		orig_village_owner = village_owner(steps.back(),teams);
-
-		if (size_t(orig_village_owner) != team_num) {
-			ui->second.set_movement(0);
-			get_village(steps.back(),teams,team_num,units);
-		}
-	}
-
 	if(move_recorder != NULL) {
 		move_recorder->add_movement(steps.front(),steps.back());
 	}
 
-	const bool event_mutated = game_events::fire("moveto",steps.back());
+	bool event_mutated = false;
+
+	int orig_village_owner = -1;
+	if(map.is_village(steps.back())) {
+		orig_village_owner = village_owner(steps.back(),teams);
+
+		if(size_t(orig_village_owner) != team_num) {
+			ui->second.set_movement(0);
+			event_mutated = get_village(steps.back(),teams,team_num,units);
+		}
+	}
+
+	if(game_events::fire("moveto",steps.back())) {
+		event_mutated = true;
+	}
 
 	if(undo_stack != NULL) {
 		if(event_mutated || should_clear_stack) {
@@ -2015,7 +2030,7 @@ bool unit_can_move(const gamemap::location& loc, const unit_map& units,
 
 	//units with goto commands that have already done their gotos this turn
 	//(i.e. don't have full movement left) should be red
-	if(u.movement_left() < u.total_movement() && u.get_goto().valid()) {
+	if(u.has_moved() && u.has_goto()) {
 		return false;
 	}
 
@@ -2040,11 +2055,12 @@ bool unit_can_move(const gamemap::location& loc, const unit_map& units,
 }
 
 void apply_shroud_changes(undo_list& undos, display* disp, const gamestatus& status, const gamemap& map,
-	const game_data& gamedata, const unit_map& units, std::vector<team>& teams, int team)
+	const game_data& gamedata, unit_map& units, std::vector<team>& teams, int team)
 {
 	// No need to do this if the team isn't using fog or shroud.
 	if(!teams[team].uses_shroud() && !teams[team].uses_fog())
 		return;
+
 	/*
 		This function works thusly:
 		1. run through the list of undo_actions
@@ -2054,18 +2070,30 @@ void apply_shroud_changes(undo_list& undos, display* disp, const gamestatus& sta
 		5. call clear_shroud to update the fog of war for each unit.
 		6. fix up associated display stuff (done in a similar way to turn_info::undo())
 	*/
-	for(undo_list::const_iterator un = undos.begin(); un != undos.end(); ++un) {
+	for(undo_list::iterator un = undos.begin(); un != undos.end(); ++un) {
+		std::cout << "Turning an undo...\n";
 		if(un->is_recall()) continue;
 		//we're not really going to mutate the unit, just temporarily
 		//set its moves to maximum, but then switch them back
-		const unit_movement_resetter move_resetter(const_cast<unit&>(un->affected_unit));
+		const unit_movement_resetter move_resetter(un->affected_unit);
 
 		std::vector<gamemap::location>::const_iterator step;
 		for(step = un->route.begin(); step != un->route.end(); ++step) {
 			//we have to swap out any unit that is already in the hex, so we can put our
 			//unit there, then we'll swap back at the end.
-			const temporary_unit_placer unit_placer(const_cast<unit_map&>(units),*step,un->affected_unit);
+			const temporary_unit_placer unit_placer(units,*step,un->affected_unit);
 			clear_shroud_unit(map,status,gamedata,units,*step,teams,team,NULL,NULL);
+
+			//FIXME
+			//there is potential for a bug, here. If the "sighted"
+			//events, raised by the clear_shroud_unit function,
+			//loops on all units, changing them all, the unit which
+			//was swapped by the temporary unit placer will not be
+			//affected. However, if we place the pump() out of the
+			//temporary_unit_placer scope, the "sighted" event will
+			//be raised with an invalid source unit, which is even
+			//worse.
+			game_events::pump();
 		}
 	}
 	if(disp != NULL) {
