@@ -1,6 +1,6 @@
-/* $Id: actions.hpp,v 1.51 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: actions.hpp 8302 2005-09-18 23:32:23Z Sirp $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@ class replay;
 
 //this file defines various functions which implement different in-game
 //events and commands.
+bool can_recruit_on(const gamemap& map, const gamemap::location& leader, const gamemap::location loc);
 
 //recruit_unit: function which recruits a unit into the game. A
 //copy of u will be created and inserted as the new recruited unit.
@@ -42,8 +43,8 @@ class replay;
 //If the unit cannot be recruited, then a human-readable message
 //describing why not will be returned. On success, the return string is empty
 std::string recruit_unit(const gamemap& map, int team, unit_map& units,
-						 unit& u, gamemap::location& recruit_location,
-                         display *disp=NULL, bool need_castle=true, bool full_movement=false);
+		unit& u, gamemap::location& recruit_location,
+		display *disp=NULL, bool need_castle=true, bool full_movement=false);
 
 //a structure which defines all the statistics for a potential
 //battle that could take place.
@@ -108,8 +109,8 @@ void attack(display& gui, const gamemap& map,
 int village_owner(const gamemap::location& loc, const std::vector<team>& teams);
 
 //makes it so the village at the given location is owned by the given
-//0-based team number
-void get_village(const gamemap::location& loc, std::vector<team>& teams,
+//0-based team number. Returns true if getting the village triggered a mutating event
+bool get_village(const gamemap::location& loc, std::vector<team>& teams,
                size_t team_num, const unit_map& units);
 
 //given the 1-based side, will find the leader of that side,
@@ -198,18 +199,18 @@ size_t move_unit(display* disp, const game_data& gamedata,
 //function which recalculates the fog
 void recalculate_fog(const gamemap& map, const gamestatus& status,
 		      const game_data& gamedata,
-		      const unit_map& units, std::vector<team>& teams, int team);
+		      unit_map& units, std::vector<team>& teams, int team);
 
 //function which will clear shroud away for the given 0-based team based on
 //current unit positions. Returns true if some shroud is actually cleared away.
 bool clear_shroud(display& disp, const gamestatus& status,
-		            const gamemap& map, const game_data& gamedata,
-                  const unit_map& units, std::vector<team>& teams, int team);
+		const gamemap& map, const game_data& gamedata,
+		unit_map& units, std::vector<team>& teams, int team);
 
 //function to apply pending shroud changes in the undo stack.
 //it needs tons of parameters because it calls clear_shroud(...) (see above)
 void apply_shroud_changes(undo_list& undos, display* disp, const gamestatus& status, const gamemap& map,
-	const game_data& gamedata, const unit_map& units, std::vector<team>& teams, int team);
+	const game_data& gamedata, unit_map& units, std::vector<team>& teams, int team);
 
 //will return true iff the unit at 'loc' has any possible moves it can do
 //(including attacking etc).
