@@ -1,6 +1,6 @@
-/* $Id: dialogs.cpp,v 1.105 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: dialogs.cpp 8269 2005-09-17 15:06:28Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -137,11 +137,14 @@ bool animate_unit_advancement(const game_data& info,unit_map& units, gamemap::lo
 		}
 	}
 
-	const std::string& chosen_unit = choice < options.size() ? options[choice] : u->second.type().id();
-	::advance_unit(info,units,loc,chosen_unit);
+	if(choice < options.size()) {
+		const std::string& chosen_unit = choice < options.size() ? options[choice] : u->second.type().id();
+		::advance_unit(info,units,loc,chosen_unit);
+	}
 
 	u = units.find(loc);
 	if(u != units.end() && choice >= options.size()) {
+		u->second.get_experience(-u->second.experience()); //reset xp to 0
 		u->second.add_modification("advance",*mod_options[choice - options.size()]);
 	}
 
@@ -751,8 +754,7 @@ void unit_preview_pane::draw_contents()
 		for(std::vector<attack_type>::const_iterator at_it = attacks.begin();
 		    at_it != attacks.end(); ++at_it) {
 
-			details << "\n"
-			        << gettext(at_it->name().c_str())
+			details << "\n" << at_it->name()
 			        << " (" << gettext(at_it->type().c_str()) << ")\n";
 			if (!at_it->special().empty())
 				details << gettext(at_it->special().c_str());
