@@ -1,6 +1,6 @@
-/* $Id: display.cpp,v 1.322 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: display.cpp 7960 2005-08-21 20:58:48Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -757,7 +757,7 @@ void display::draw(bool update,bool force)
 		lastDraw_ = SDL_GetTicks();
 
 		if(wait_time >= 0 || drawSkips_ >= max_skips || force) {
-			if(changed) {
+			if(changed || force) {
 				update_display();
 			}
 		} else {
@@ -938,7 +938,7 @@ void display::draw_report(reports::TYPE report_num)
 			std::string str = item->prefix();
 			if(str.empty() == false) {
 				report.insert(report.begin(), reports::element(str,"",report.begin()->tooltip));
-				}
+			}
 			str = item->postfix();
 			if(str.empty() == false) {
 				report.push_back(reports::element(str,"",report.end()->tooltip));
@@ -993,143 +993,6 @@ void display::draw_report(reports::TYPE report_num)
 	}
 }
 
-#if 0
-void display::draw_unit_details(int x, int y, const gamemap::location& loc,
-         const unit& u, SDL_Rect& description_rect, int profilex, int profiley,
-         SDL_Rect* clip_rect)
-{
-	if(teams_.empty())
-		return;
-
-	tooltips::clear_tooltips(description_rect);
-
-	SDL_Rect clipRect = clip_rect != NULL ? *clip_rect : screen_area();
-
-	const surface background(image::get_image(game_config::rightside_image,image::UNSCALED));
-	const surface background_bot(image::get_image(game_config::rightside_image_bot,image::UNSCALED));
-
-	if(background == NULL || background_bot == NULL)
-		return;
-
-	surface const screen(screen_.getSurface());
-
-	if(description_rect.w > 0 && description_rect.x >= mapx()) {
-		SDL_Rect srcrect = description_rect;
-		srcrect.y -= background->h;
-		srcrect.x -= mapx();
-
-		SDL_BlitSurface(background_bot,&srcrect,screen,&description_rect);
-		update_rect(description_rect);
-	}
-
-	std::string status = _("healthy");
-	if(map_.on_board(loc) &&
-	   u.invisible(map_.underlying_terrain(map_[loc.x][loc.y]),
-			status_.get_time_of_day().lawful_bonus,loc,
-			units_,teams_)) {
-		status = font::GOOD_TEXT + _("invisible");
-	}
-
-	if(u.has_flag("slowed")) {
-		status = font::BAD_TEXT + _("slowed");
-	}
-
-	if(u.has_flag("poisoned")) {
-		status = font::BAD_TEXT + _("poisoned");
-	}
-
-	std::stringstream details;
-	details << font::LARGE_TEXT << u.description() << "\n"
-	        << font::LARGE_TEXT << u.type().language_name()
-			<< "\n" << font::SMALL_TEXT << "(" << _("level") << " "
-			<< u.type().level() << ")\n"
-			<< status << "\n"
-			<< string_table[unit_type::alignment_description(u.type().alignment())]
-			<< "\n"
-			<< u.traits_description() << "\n";
-
-	const std::vector<std::string>& abilities = u.type().abilities();
-	for(std::vector<std::string>::const_iterator a = abilities.begin(); a != abilities.end(); ++a) {
-		details << *a << "\n";
-	}
-
-	//display in green/white/red depending on hitpoints
-	if(u.hitpoints() <= u.max_hitpoints()/3)
-		details << font::BAD_TEXT;
-	else if(u.hitpoints() > 2*(u.max_hitpoints()/3))
-		details << font::GOOD_TEXT;
-
-	details << _("HP: ") << u.hitpoints()
-			<< "/" << u.max_hitpoints() << "\n";
-
-	if(u.can_advance() == false) {
-		details << _("XP: ") << u.experience() << "/-";
-	} else {
-		//if killing a unit the same level as us would level us up,
-		//then display in green
-		if(u.max_experience() - u.experience() < game_config::kill_experience) {
-			details << font::GOOD_TEXT;
-		}
-
-		details << _("XP: ") << u.experience() << "/" << u.max_experience();
-	}
-
-	details << "\n"
-			<< _("Moves: ") << u.movement_left() << "/"
-			<< u.total_movement()
-			<< "\n";
-
-	const std::vector<attack_type>& attacks = u.attacks();
-	for(std::vector<attack_type>::const_iterator at_it = attacks.begin();
-	    at_it != attacks.end(); ++at_it) {
-
-		const t_string& lang_weapon = at_it->name();
-		const std::string& lang_type = at_it->type();
-		const std::string& lang_special = at_it->special();
-		details << "\n"
-				<< (lang_weapon.empty() ? at_it->name():lang_weapon) << " ("
-				<< (lang_type.empty() ? at_it->type():lang_type) << ")\n"
-				<< (lang_special.empty() ? at_it->special():lang_special)<<"\n"
-				<< at_it->damage() << "-" << at_it->num_attacks() << " -- "
-		        << (at_it->range() == attack_type::SHORT_RANGE ?
-		            _("melee") :
-					_("ranged"));
-
-		details << "\n\n";
-	}
-
-	//choose the font size based on how much room we have to play
-	//with on the right-side panel
-	const size_t font_size = this->y() >= 700 ? 13 : 10;
-
-	description_rect = font::draw_text(&screen_,clipRect,font_size,font::NORMAL_COLOUR,
-	                                   details.str(),x,y);
-
-	update_rect(description_rect);
-
-	y += description_rect.h;
-
-	const surface profile(image::get_image(u.type().image(),image::UNSCALED));
-
-	if(profile == NULL)
-		return;
-
-	//blit the unit profile
-	{
-		const size_t profilew = 50;
-		const size_t profileh = 50;
-		SDL_Rect srcrect = { (profile->w-profilew)/2,(profile->h-profileh)/2,
-		                     profilew,profileh };
-		SDL_Rect dstrect = srcrect;
-		dstrect.x = profilex;
-		dstrect.y = profiley;
-		SDL_BlitSurface(profile,&srcrect,video().getSurface(),&dstrect);
-
-		update_rect(profilex,profiley,profilew,profileh);
-	}
-}
-#endif
-
 void display::draw_minimap(int x, int y, int w, int h)
 {
 	const surface surf(get_minimap(w,h));
@@ -1550,7 +1413,6 @@ void display::draw_tile(int x, int y, surface unit_image, fixed_t alpha, Uint32
 				SDL_BlitSurface(overlay_surface,NULL,dst,&dstrect);
 			}
 		}
-		draw_footstep(loc,xpos,ypos);
 	} else {
 		//FIXME: shouldn't void.png and fog.png be in the program configuration?
 		surface surface(image::get_image("terrain/void.png"));
@@ -1564,10 +1426,12 @@ void display::draw_tile(int x, int y, surface unit_image, fixed_t alpha, Uint32
 		SDL_BlitSurface(surface,NULL,dst,&dstrect);
 	}
 
+	draw_footstep(loc,xpos,ypos);
 	draw_unit_on_tile(x,y,unit_image,alpha,blend_to);
 
-	if(!shrouded(x,y)) {
+	if(!is_shrouded) {
 		draw_terrain_on_tile(x,y,image_type,ADJACENT_FOREGROUND);
+		draw_movement_info(loc,xpos,ypos);
 	}
 
 	if(fogged(x,y) && shrouded(x,y) == false) {
@@ -1626,8 +1490,6 @@ void display::draw_footstep(const gamemap::location& loc, int xloc, int yloc)
 	if(i == route_.steps.begin() || i == route_.steps.end())
 		return;
 
-	const bool show_time = (i+1 == route_.steps.end());
-
 	const bool left_foot = is_even(i - route_.steps.begin());
 
 	//generally we want the footsteps facing toward the direction they're going
@@ -1698,6 +1560,13 @@ void display::draw_footstep(const gamemap::location& loc, int xloc, int yloc)
 	}
 
 	draw_unit(xloc,yloc,image,vflip,ftofxp(0.5));
+}
+
+void display::draw_movement_info(const gamemap::location& loc, int xloc, int yloc)
+{
+	std::vector<gamemap::location>::const_iterator i =
+	         std::find(route_.steps.begin(),route_.steps.end(),loc);
+	const bool show_time = (i+1 == route_.steps.end());
 
 	if(show_time == false) {
 		return;
@@ -1706,6 +1575,7 @@ void display::draw_footstep(const gamemap::location& loc, int xloc, int yloc)
 	std::stringstream text;
 
 #ifndef USE_TINY_GUI
+	const unit_map::const_iterator un = units_.find(route_.steps.front());
 	if(un != units_.end() && zoom_ >= DefaultZoom) {
 		text << (100-un->second.defense_modifier(map_,map_.get_terrain(loc))) << "%";
 	}
