@@ -1,6 +1,6 @@
-/* $Id: display.hpp,v 1.104 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: display.hpp 7949 2005-08-21 16:22:15Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -208,6 +208,9 @@ public:
 	//return with no effect.
 	void draw_footstep(const gamemap::location& loc, int xloc, int yloc);
 
+	//draws the movement info (turns available) for a given location
+	void draw_movement_info(const gamemap::location& loc, int xloc, int yloc);
+
 	//gets the underlying screen object.
 	CVideo& video() { return screen_; }
 
