@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+  Copyright (C) 2003 by David White <davidnwhite@verizon.net>
   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
   This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #include "../game_config.hpp"
 #include "../gettext.hpp"
 #include "../key.hpp"
+#include "../language.hpp"
 #include "../widgets/menu.hpp"
 #include "../pathfind.hpp"
 #include "../playlevel.hpp"
@@ -42,6 +43,7 @@
 #include <cctype>
 #include <iostream>
 #include <map>
+#include <vector>
 #include <string>
 #include <cmath>
 
@@ -91,7 +93,7 @@ map_editor::map_editor(display &gui, gamemap &map, config &theme, config &game_c
 	  theme_(theme), game_config_(game_config), map_dirty_(false), l_button_palette_dirty_(true),
 	  everything_dirty_(false), palette_(gui, size_specs_, map), brush_(gui, size_specs_),
 	  l_button_held_func_(NONE), highlighted_locs_cleared_(false), prefs_disp_manager_(&gui_),
-	  all_hexes_selected_(false) {
+	  all_hexes_selected_(false), tooltip_manager_(gui_.video()), floating_label_manager_() {
 
 	// Set size specs.
 	adjust_sizes(gui_, size_specs_);
@@ -117,6 +119,7 @@ map_editor::map_editor(display &gui, gamemap &map, config &theme, config &game_c
 		palette_.select_bg_terrain(old_bg_terrain_);
 		brush_.select_brush_size(old_brush_size_);
 	}
+
 	hotkey::load_descriptions();
 	recalculate_starting_pos_labels();
 	gui_.invalidate_game_status();
@@ -127,6 +130,61 @@ map_editor::map_editor(display &gui, gamemap &map, config &theme, config &game_c
 	brush_.adjust_size();
 	events::raise_draw_event();
 	redraw_everything();
+	load_tooltips();
+}
+
+/**
+ * This should be replaced by a WML tag called 'tooltip=' in the
+ * data/themes/editor.cfg file. The theme and display classes
+ * should then load the given tooltip in the button.
+ */
+void map_editor::load_tooltips()
+{
+	// Clear all previous tooltips
+	tooltips::clear_tooltips();
+
+	// Add tooltips to all buttons
+	const theme &t = gui_.get_theme();
+        const std::vector<theme::menu> &menus = t.menus();
+        std::vector<theme::menu>::const_iterator it;
+        for (it = menus.begin(); it != menus.end(); it++) {
+
+		// Get the button's screen location
+		SDL_Rect screen;
+		screen.x = 0; screen.y = 0; screen.w = gui_.x(); screen.h = gui_.y();
+
+		const SDL_Rect tooltip_rect = (*it).location(screen);
+		std::string text = "";
+
+		const std::vector<std::string> &menu_items = (*it).items();
+		if (menu_items.size() == 1) {
+			if(menu_items.back() == "editdraw")
+				text = _("Draw tiles");
+			else if(menu_items.back() == "editfloodfill")
+				text = _("Fill");
+			else if(menu_items.back() == "editsetstartpos")
+				text = _("Set player's starting position");
+			else if(menu_items.back() == "zoomin")
+				text = _("Zoom in");
+			else if(menu_items.back() == "zoomout")
+				text = _("Zoom out");
+			else if(menu_items.back() == "undo")
+				text = _("Undo");
+			else if(menu_items.back() == "redo")
+				text = _("Redo");
+			else if(menu_items.back() == "zoomdefault")
+				text = _("Zoom to default view");
+			else if(menu_items.back() == "togglegrid")
+				text = _("Toggle grid");
+			else if(menu_items.back() == "editresize")
+				text = _("Resize the map");
+			else if(menu_items.back() == "editflip")
+				text = _("Flip map");
+		}
+
+		if(text != "")
+			tooltips::add_tooltip(tooltip_rect, text);
+        }
 }
 
 map_editor::~map_editor() {
@@ -150,12 +208,15 @@ void map_editor::handle_event(const SDL_Event &event) {
 		everything_dirty_ = true;
 	}
 	int mousex, mousey;
+
 	SDL_GetMouseState(&mousex,&mousey);
 	const SDL_KeyboardEvent keyboard_event = event.key;
 	handle_keyboard_event(keyboard_event, mousex, mousey);
 
 	const SDL_MouseButtonEvent mouse_button_event = event.button;
 	handle_mouse_button_event(mouse_button_event, mousex, mousey);
+
+	tooltips::process(mousex, mousey);
 }
 
 void map_editor::handle_keyboard_event(const SDL_KeyboardEvent &event,
@@ -298,17 +359,60 @@ void map_editor::right_click(const gamemap::location hex_clicked ) {
 	}
 }
 
+// Set the language...
+void map_editor::change_language() {
+	std::vector<language_def> langdefs = get_languages();
+
+	// this only works because get_languages() returns a fresh vector at each calls
+	// unless show_gui cleans the "*" flag
+	const std::vector<language_def>::iterator current = std::find(langdefs.begin(),langdefs.end(),get_language());
+	if(current != langdefs.end()) {
+		(*current).language = "*" + (*current).language;
+	}
+
+	// prepare a copy with just the labels for the list to be displayed
+	std::vector<std::string> langs;
+	langs.reserve(langdefs.size());
+	std::transform(langdefs.begin(),langdefs.end(),std::back_inserter(langs),languagedef_name);
+
+	const int res = gui::show_dialog(gui_,NULL,_("Language"),
+	                         _("Choose your preferred language:"),
+	                         gui::OK_CANCEL,&langs);
+	if(size_t(res) < langs.size()) {
+		::set_language(known_languages[res]);
+		preferences::set_language(known_languages[res].localename);
+
+		game_config_.reset_translation();
+
+		// Reload tooltips and menu items
+		load_tooltips();
+	}
+
+	font::load_font_config();
+	hotkey::load_descriptions();
+}
+
 
 void map_editor::edit_save_as() {
 	const std::string default_dir =
 		get_dir(get_dir(get_user_data_dir() + "/editor") + "/maps/");
 	std::string input_name = filename_.empty() ? default_dir : filename_;
+	const std::string old_input_name = input_name;
+
 	int res = 0;
-	int overwrite = 0;
+	int overwrite = 1;
 	do {
+		input_name = old_input_name;
 		res = dialogs::show_file_chooser_dialog(gui_, input_name, _("Save the Map As"));
 		if (res == 0) {
-			if (file_exists(input_name)) {
+
+			// Check whether the filename contains illegal characters
+			if(!verify_filename(input_name, true))
+			{
+				input_name = old_input_name;
+				continue;
+			}
+			else if (file_exists(input_name)) {
 				overwrite = gui::show_dialog(gui_, NULL, "",
 					_("The map already exists. Do you want to overwrite it?"),
 					gui::YES_NO);
@@ -318,9 +422,14 @@ void map_editor::edit_save_as() {
 		}
 	} while (res == 0 && overwrite != 0);
 
+	// Try to save the map, if it fails we reset the filename.
 	if (res == 0) {
+		std::string old_file_name = filename_;
 		set_file_to_save_as(input_name);
-		save_map("", true);
+		if(!save_map("", true))
+		{
+			filename_ = old_file_name;
+		}
 	}
 }
 
@@ -328,7 +437,7 @@ void map_editor::perform_set_starting_pos() {
 	std::vector<std::string> players;
 	for (int i = 0; i < num_players; i++) {
 		std::stringstream str;
-		str << "Player " << i + 1;
+		str << _("Player ") << i + 1;
 		players.push_back(str.str());
 	}
 	int res = gui::show_dialog(gui_, NULL, _("Which Player?"),
@@ -386,6 +495,11 @@ void map_editor::edit_load_map() {
 		get_dir(get_dir(get_user_data_dir() + "/editor") + "/maps/") : filename_;
 	int res = dialogs::show_file_chooser_dialog(gui_, fn, _("Choose a Map to Load"));
 	if (res == 0) {
+		// Check if the mapname contains any illegal characters
+		if(!verify_filename(fn, false))	{
+			gui::show_dialog(gui_, NULL, "", _("Warning: Illegal characters found in the map name. You've to save under a different name."), gui::OK_ONLY);
+		}
+
 		std::string new_map;
 		try {
 			new_map = load_map(fn);
@@ -599,6 +713,7 @@ bool map_editor::can_execute_command(hotkey::HOTKEY_COMMAND command) const {
 	case hotkey::HOTKEY_ZOOM_OUT:
 	case hotkey::HOTKEY_ZOOM_DEFAULT:
 	case hotkey::HOTKEY_FULLSCREEN:
+	case hotkey::HOTKEY_SCREENSHOT:
 	case hotkey::HOTKEY_TOGGLE_GRID:
 	case hotkey::HOTKEY_PREFERENCES:
 	case hotkey::HOTKEY_EDIT_SAVE_MAP:
@@ -618,6 +733,7 @@ bool map_editor::can_execute_command(hotkey::HOTKEY_COMMAND command) const {
 	case hotkey::HOTKEY_EDIT_SELECT_ALL:
 	case hotkey::HOTKEY_EDIT_DRAW:
 	case hotkey::HOTKEY_EDIT_REFRESH:
+	case hotkey::HOTKEY_LANGUAGE:
 		return true;
 	default:
 		return false;
@@ -716,6 +832,7 @@ void map_editor::redraw_everything() {
 	update_l_button_palette();
 	palette_.draw(true);
 	brush_.draw(true);
+	load_tooltips();
 }
 
 void map_editor::highlight_selected_hexes(const bool clear_old) {
@@ -1024,6 +1141,14 @@ bool map_editor::save_map(const std::string fn, const bool display_confirmation)
 	else {
 		filename_ = filename;
 	}
+
+	// Check if the filename is correct before saving. We do this
+	// twice (also in the 'save as' routine), because a file might
+	// already contain illegal characters if loaded.
+	if(!verify_filename(filename, display_confirmation)) {
+		return false;
+	}
+
 	try {
 		write_file(filename, map_.write());
 		num_operations_since_save_ = 0;
@@ -1042,6 +1167,21 @@ bool map_editor::save_map(const std::string fn, const bool display_confirmation)
 	return true;
 }
 
+bool map_editor::verify_filename(const std::string& filename, bool show_error) const
+{
+	static const std::string allowed_characters = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_/\\.";
+	static const std::string prefix = "\\/";
+	std::size_t start_pos = filename.find_last_of(prefix);
+
+	if(filename.find_first_not_of(allowed_characters, start_pos) != std::string::npos) {
+		if(show_error) {
+			gui::show_dialog(gui_, NULL, "", _("Error: Illegal character in filename."), gui::OK_ONLY);
+		}
+		return false;
+	}
+
+	return true;
+}
 void map_editor::show_menu(const std::vector<std::string>& items_arg, const int xloc,
 						   const int yloc, const bool /*context_menu*/) {
 	std::vector<std::string> items = items_arg;
