@@ -1,6 +1,6 @@
-/* $Id: game.cpp,v 1.259 2005/06/28 16:23:46 Sirp Exp $ */
+/* $Id: game.cpp 8285 2005-09-18 19:08:31Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -85,7 +85,7 @@ bool less_campaigns_rank(const config* a, const config* b) {
 class game_controller
 {
 public:
-	game_controller(int argc, char** argv, bool use_sound);
+	game_controller(int argc, char** argv);
 
 	display& disp();
 
@@ -120,6 +120,7 @@ private:
 	void download_campaigns();
 	void upload_campaign(const std::string& campaign, network::connection sock);
 	void delete_campaign(const std::string& campaign, network::connection sock);
+	void remove_campaign(const std::string& campaign);
 
 	const int argc_;
 	int arg_;
@@ -132,8 +133,8 @@ private:
 	CVideo video_;
 
 	const font::manager font_manager_;
-	const sound::manager sound_manager_;
 	const preferences::manager prefs_manager_;
+	const sound::manager sound_manager_;
 	const image::manager image_manager_;
 	const events::event_context main_event_context_;
 	const hotkey::manager hotkey_manager_;
@@ -156,9 +157,9 @@ private:
 	preproc_map defines_map_, old_defines_map_;
 };
 
-game_controller::game_controller(int argc, char** argv, bool use_sound)
+game_controller::game_controller(int argc, char** argv)
    : argc_(argc), arg_(1), argv_(argv), thread_manager(),
-     sound_manager_(use_sound), test_mode_(false), multiplayer_mode_(false),
+     test_mode_(false), multiplayer_mode_(false),
      no_gui_(false), use_caching_(true), force_bpp_(-1), disp_(NULL),
      loaded_game_show_replay_(false)
 {
@@ -206,7 +207,8 @@ game_controller::game_controller(int argc, char** argv, bool use_sound)
 			game_config::debug = true;
 		} else if (val.substr(0, 6) == "--log-") {
 		} else if(val == "--nosound") {
-			//handled elsewhere
+			preferences::set_sound(false);
+			preferences::set_music(false);
 		} else if(val[0] == '-') {
 			std::cerr << "unknown option: " << val << std::endl;
 			throw config::error("unknown option");
@@ -226,6 +228,13 @@ game_controller::game_controller(int argc, char** argv, bool use_sound)
 
 		}
 	}
+
+	if (preferences::sound_on() || preferences::music_on()) {
+		if(!sound::init_sound()) {
+			preferences::set_sound(false);
+			preferences::set_music(false);
+		}
+	}
 }
 
 display& game_controller::disp()
@@ -265,50 +274,56 @@ bool game_controller::init_video()
 
 	std::pair<int,int> resolution = preferences::resolution();
 
+	int DefaultBPP = 24;
+	const SDL_VideoInfo* const video_info = SDL_GetVideoInfo();
+	if(video_info != NULL && video_info->vfmt != NULL) {
+		DefaultBPP = video_info->vfmt->BitsPerPixel;
+	}
+
 	std::cerr << "Checking video mode: " << resolution.first
-		  << "x" << resolution.second << "x16...\n";
-	int bpp = video_.modePossible(resolution.first,resolution.second,16,video_flags);
+		  << "x" << resolution.second << "x" << DefaultBPP << "...\n";
+	int bpp = video_.modePossible(resolution.first,resolution.second,DefaultBPP,video_flags);
 
 	std::cerr << bpp << "\n";
 
 	if(bpp == 0) {
 		//Video mode not supported, maybe from bad prefs.
 		std::cerr << "Video mode " << resolution.first
-		          << "x" << resolution.second << "x16 "
-		          << "is not supported - attempting 1024x768x16...\n";
+		          << "x" << resolution.second << "x" << DefaultBPP << " "
+		          << "is not supported - attempting 1024x768x" << DefaultBPP << "...\n";
 
 		//Attempt 1024x768.
 		resolution.first = 1024;
 		resolution.second = 768;
 
-		bpp = video_.modePossible(resolution.first,resolution.second,16,video_flags);
+		bpp = video_.modePossible(resolution.first,resolution.second,DefaultBPP,video_flags);
 
 		if(bpp == 0) {
-			std::cerr << "1024x768x16 not available - attempting 800x600x16...\n";
+			std::cerr << "1024x768x" << DefaultBPP << " not available - attempting 800x600x" << DefaultBPP << "...\n";
 
 			resolution.first = 800;
 			resolution.second = 600;
 
-			bpp = video_.modePossible(resolution.first,resolution.second,16,video_flags);
+			bpp = video_.modePossible(resolution.first,resolution.second,DefaultBPP,video_flags);
 		}
 
 #ifdef USE_TINY_GUI
 		if(bpp == 0) {
-			std::cerr << "800x600x16 not available - attempting 640x480x16...\n";
+			std::cerr << "800x600x" << DefaultBPP << " not available - attempting 640x480x" << DefaultBPP << "...\n";
 
 			resolution.first = 640;
 			resolution.second = 480;
 
-			bpp = video_.modePossible(resolution.first,resolution.second,16,video_flags);
+			bpp = video_.modePossible(resolution.first,resolution.second,DefaultBPP,video_flags);
 		}
 
 		if(bpp == 0) {
-			std::cerr << "640x480x16 not available - attempting 320x240x16...\n";
+			std::cerr << "640x480x" << DefaultBPP << " not available - attempting 320x240x" << DefaultBPP << "...\n";
 
 			resolution.first = 320;
 			resolution.second = 240;
 
-			bpp = video_.modePossible(resolution.first,resolution.second,16,video_flags);
+			bpp = video_.modePossible(resolution.first,resolution.second,DefaultBPP,video_flags);
 		}
 #endif
 
@@ -316,12 +331,12 @@ bool game_controller::init_video()
 			//couldn't do 1024x768 or 800x600
 
 			std::cerr << "The required video mode, " << resolution.first
-			          << "x" << resolution.second << "x16 "
+			          << "x" << resolution.second << "x" << DefaultBPP << " "
 			          << "is not supported\n";
 
 			if((video_flags&FULL_SCREEN) != 0) {
 				std::cerr << "Try running the program with the --windowed option "
-				          << "using a 16bpp X windows setting\n";
+				          << "using a " << DefaultBPP << "bpp X windows setting\n";
 			}
 
 			if((video_flags&FULL_SCREEN) == 0) {
@@ -565,6 +580,7 @@ bool game_controller::play_multiplayer_mode()
 	}
 
 	try {
+		state_.snapshot = level;
 		::play_game(disp(),state_,game_config_,units_data_,video_);
 		//play_level(units_data_,game_config_,&level,video_,state_,story);
 	} catch(game::error& e) {
@@ -739,14 +755,13 @@ bool game_controller::new_campaign()
 	std::vector<gui::preview_pane*> preview_panes;
 	preview_panes.push_back(&campaign_preview);
 
-	if(campaign_names.size() > 1) {
-		res = gui::show_dialog(disp(),NULL,_("Campaign"),
-				_("Choose the campaign you want to play:"),
-				gui::OK_CANCEL,&campaign_names,&preview_panes);
+	wassert(campaign_names.size() > 0);
+	res = gui::show_dialog(disp(),NULL,_("Campaign"),
+			_("Choose the campaign you want to play:"),
+			gui::OK_CANCEL,&campaign_names,&preview_panes);
 
-		if(res == -1) {
-			return false;
-		}
+	if(res == -1) {
+		return false;
 	}
 
 	//get more campaigns from server
@@ -916,7 +931,16 @@ void game_controller::download_campaigns()
 			//add negative sizes to reverse the sort order
 			sizes.push_back(-atoi((**i)["size"].c_str()));
 
-			options.push_back(IMAGE_PREFIX + (**i)["icon"].str() + COLUMN_SEPARATOR +
+			const int max_icon_dim = 80;
+
+			//make sure the icon isn't too big
+			std::string icon = (**i)["icon"];
+			const surface icon_img = image::get_image(icon,image::UNSCALED);
+			if(icon_img.null() == false && icon_img->w > max_icon_dim && icon_img->h > max_icon_dim) {
+				icon = "";
+			}
+
+			options.push_back(IMAGE_PREFIX + icon + COLUMN_SEPARATOR +
 			                  title + COLUMN_SEPARATOR +
 			                  version + COLUMN_SEPARATOR +
 			                  author + COLUMN_SEPARATOR +
@@ -972,6 +996,11 @@ void game_controller::download_campaigns()
 			return;
 		}
 
+		//remove any existing versions of the just downloaded campaign
+		//assuming it consists of a dir and a cfg file
+		remove_campaign(campaigns[index]);
+
+		//put a break at line below to see that it really works.
 		unarchive_campaign(cfg);
 
 		// when using zipios, force a reread zip and directory indices
@@ -986,6 +1015,10 @@ void game_controller::download_campaigns()
 		old_defines_map_.clear();
 		refresh_game_cfg();
 		use_caching_ = old_cache;
+		::init_textdomains(game_config_);
+		paths_manager_.set_paths(game_config_);
+
+		clear_binary_paths_cache();
 
 		gui::show_dialog(disp(),NULL,_("Campaign Installed"),_("The campaign has been installed."),gui::OK_ONLY);
 	} catch(config::error&) {
@@ -1027,10 +1060,9 @@ void game_controller::upload_campaign(const std::string& campaign, network::conn
 		for(size_t n = 0; n != 8; ++n) {
 			passphrase[n] = 'a' + (rand()%26);
 		}
-
+		cfg["passphrase"] = passphrase;
 		set_campaign_info(campaign,cfg);
 	}
-	cfg["passphrase"] = passphrase;
 
 	cfg["name"] = campaign;
 
@@ -1043,7 +1075,7 @@ void game_controller::upload_campaign(const std::string& campaign, network::conn
 	std::cerr << "uploading campaign...\n";
 	network::send_data(data,sock);
 
-	sock = network::receive_data(data,sock,5000);
+	sock = gui::network_data_dialog(disp(),_("Awaiting response from server"),data,sock);
 	if(!sock) {
 		gui::show_error_message(disp(), _("Connection timed out"));
 	} else if(data.child("error")) {
@@ -1079,6 +1111,13 @@ void game_controller::delete_campaign(const std::string& campaign, network::conn
 	}
 }
 
+void game_controller::remove_campaign(const std::string& campaign)
+{
+	const std::string campaign_dir = get_user_data_dir() + "/data/campaigns/" + campaign;
+	delete_directory(campaign_dir);
+	delete_directory(campaign_dir + ".cfg");
+}
+
 bool game_controller::play_multiplayer()
 {
 	state_ = game_state();
@@ -1269,6 +1308,7 @@ void game_controller::read_game_cfg(const preproc_map& defines, config& cfg, boo
 				scoped_istream stream = preprocess_file("data/game.cfg", &defines_map);
 
 				std::string error_log, user_error_log;
+
 				read(cfg, *stream, &error_log);
 
 				//load user campaigns
@@ -1282,7 +1322,8 @@ void game_controller::read_game_cfg(const preproc_map& defines, config& cfg, boo
 					}
 
 					try {
-						scoped_istream stream = preprocess_file(*uc,&defines_map);
+						preproc_map user_defines_map(defines_map);
+						scoped_istream stream = preprocess_file(*uc,&user_defines_map);
 
 						std::string campaign_error_log;
 
@@ -1433,8 +1474,6 @@ int play_game(int argc, char** argv)
 {
 	const int start_ticks = SDL_GetTicks();
 
-	bool use_sound = true;
-
 	//parse arguments that shouldn't require a display device
 	int arg;
 	for(arg = 1; arg != argc; ++arg) {
@@ -1472,8 +1511,6 @@ int play_game(int argc, char** argv)
 			std::cout <<  game_config::path
 			          << "\n";
 			return 0;
-		} else if(val == "--nosound") {
-			use_sound = false;
 		} else if (val.substr(0, 6) == "--log-") {
 			size_t p = val.find('=');
 			if (p == std::string::npos) {
@@ -1540,7 +1577,7 @@ int play_game(int argc, char** argv)
 
 	srand(time(NULL));
 
-	game_controller game(argc,argv,use_sound);
+	game_controller game(argc,argv);
 
 	if (!filesystem_init()) {
 		std::cerr << "cannot init filesystem code\n";
@@ -1613,6 +1650,9 @@ int play_game(int argc, char** argv)
 	SDL_EventState(SDL_SYSWMEVENT, SDL_ENABLE);
 #endif
 
+	int ntip = -1;
+	config tips_of_day;
+
 	for(;;) {
 		//make sure the game config is always set to how it should be at the title screen
 		game.reset_game_cfg();
@@ -1638,12 +1678,9 @@ int play_game(int argc, char** argv)
 		std::cerr << (SDL_GetTicks() - start_ticks) << "\n";
 		gui::TITLE_RESULT res = game.is_loading() ? gui::LOAD_GAME : gui::TITLE_CONTINUE;
 
-		int ntip = -1;
-		config tips_of_day;
 		while(res == gui::TITLE_CONTINUE) {
 			res = gui::show_title(game.disp(),tips_of_day,&ntip);
 		}
-		tips_of_day.clear();
 
 		game_controller::RELOAD_GAME_DATA should_reload = game_controller::RELOAD_DATA;
 		std::cerr << "title screen returned result\n";
@@ -1668,8 +1705,10 @@ int play_game(int argc, char** argv)
 			}
 		} else if(res == gui::CHANGE_LANGUAGE) {
 			if(game.change_language() == false) {
+				tips_of_day.clear();
 				continue;
 			}
+			tips_of_day.clear();
 		} else if(res == gui::EDIT_PREFERENCES) {
 			game.show_preferences();
 			continue;
@@ -1679,6 +1718,7 @@ int play_game(int argc, char** argv)
 		}
 
 		game.play_game(should_reload);
+		ntip = -1; // Change tip when a game is played
 	}
 
 	return 0;
