@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -877,9 +877,10 @@ std::vector<topic> generate_topics(const std::string &generator)
 	else if (generator == "weapon_specials") {
 		res = generate_weapon_special_topics();
 	}
-	else if (generator == "terrains") {
-		res = generate_terrains_topics();
-	}
+//  terrain topics removed for now, since they aren't release-quality
+//	else if (generator == "terrains") {
+//		res = generate_terrains_topics();
+//	}
 	std::sort(res.begin(), res.end(), title_less());
 	return res;
 }
@@ -1094,7 +1095,9 @@ public:
 		ss << _("HP: ") << type_.hitpoints() << jump(30)
 		   << _("Moves: ") << type_.movement() << jump(30)
 		   << _("Alignment: ")
+		   << "<ref>dst='time_of_day' text='"
 		   << type_.alignment_description(type_.alignment())
+		   << "'</ref>"
 		   << jump(30);
 		if (type_.can_advance())
 			ss << _("Required XP: ") << type_.experience_needed();
@@ -1123,7 +1126,7 @@ public:
 			for(std::vector<attack_type>::const_iterator attack_it = attacks.begin(),
 				 attack_end = attacks.end();
 				 attack_it != attack_end; ++attack_it) {
-				std::string lang_weapon = gettext(attack_it->name().c_str());
+				std::string lang_weapon = attack_it->name();
 				std::string lang_type = gettext(attack_it->type().c_str());
 				std::vector<item> row;
 				std::stringstream attack_ss;
@@ -1197,21 +1200,22 @@ public:
 
 			table.push_back(first_row);
 			for (std::set<std::string>::const_iterator terrain_it =
-					 preferences::encountered_terrains().begin(),
-				 terrain_end = preferences::encountered_terrains().end();
-				 terrain_it != terrain_end; terrain_it++) {
+				  preferences::encountered_terrains().begin(),
+				  terrain_end = preferences::encountered_terrains().end();
+				  terrain_it != terrain_end; terrain_it++) {
 				wassert(terrain_it->size() > 0);
 				const gamemap::TERRAIN terrain = (*terrain_it)[0];
 				if (terrain == gamemap::FOGGED || terrain == gamemap::VOID_TERRAIN)
 					continue;
 				const terrain_type& info = map->get_terrain_info(terrain);
-				if (!info.is_alias()) {
+				if (!info.is_alias() && info.is_nonnull()) {
 					std::vector<item> row;
 					const std::string& name = info.name();
+					const std::string id = info.id();
 					const int moves = movement_type.movement_cost(*map,terrain);
 					std::stringstream str;
 					str << "<ref>text='" << escape(name) << "' dst='"
-					    << escape(std::string("terrain_") + terrain) << "'</ref>";
+					    << escape(std::string("terrain_") + id) << "'</ref>";
 					row.push_back(std::make_pair(str.str(),
 								     font::line_width(name,
 										      normal_font_size)));
@@ -1291,7 +1295,7 @@ struct terrain_topic_generator: topic_generator
 			const std::string aliased_terrains = type.type();
 			std::stringstream alias_ss;
 			for (std::string::const_iterator it = aliased_terrains.begin();
-				 it != aliased_terrains.end(); it++) {
+				  it != aliased_terrains.end(); it++) {
 				const gamemap::TERRAIN t = *it;
 				const std::string &alias_name = map->get_terrain_info(t).name();
 				alias_ss << "<ref>text='" << escape(alias_name) << "' dst='"
