@@ -1,6 +1,6 @@
-/* $Id: hotkeys.hpp,v 1.61 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: hotkeys.hpp 8267 2005-09-17 14:01:49Z morloth $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -41,7 +41,7 @@ enum HOTKEY_COMMAND {
 	HOTKEY_LABEL_TERRAIN, HOTKEY_SHOW_ENEMY_MOVES, HOTKEY_BEST_ENEMY_MOVES,
 	HOTKEY_DELAY_SHROUD, HOTKEY_UPDATE_SHROUD, HOTKEY_CONTINUE_MOVE,
 	HOTKEY_SEARCH, HOTKEY_SPEAK_ALLY, HOTKEY_SPEAK_ALL, HOTKEY_HELP,
-	HOTKEY_CHAT_LOG,
+	HOTKEY_CHAT_LOG, HOTKEY_LANGUAGE,
 
 	//editing specific commands
 	HOTKEY_EDIT_SET_TERRAIN,
@@ -162,6 +162,7 @@ public:
 	virtual void show_help() {}
 	virtual void show_chat_log() {}
 	virtual void user_command() {}
+	virtual void change_language() {}
 
 	// Map editor stuff.
 	virtual void edit_set_terrain() {}
