@@ -1,7 +1,7 @@
-/* $Id: language.cpp,v 1.96 2005/06/24 22:41:49 Sirp Exp $ */
+/* $Id: language.cpp 8326 2005-09-19 19:38:01Z ott $ */
 /* vim:set encoding=utf-8: */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -39,34 +39,36 @@ namespace {
 
 language_def known_languages[] = {
 	language_def("", N_("System default language")),
-	language_def("bg_BG", "Български (Bulgarski)"),
+	language_def("af_ZA", "Afrikaans"),
+	//language_def("bg_BG", "Български (Bulgarski)"),
 	language_def("ca_ES", "Català"),
 	language_def("cs_CZ", "Čeština"),
-	language_def("da_DK", "Dansk"),
+	//language_def("da_DK", "Dansk"),
 	language_def("de_DE", "Deutsch"),
-	language_def("el_GR", "Ελληνικά (Ellinika)"),
-	language_def("et_EE", "Eesti"),
+	//language_def("el_GR", "Ελληνικά (Ellinika)"),
+	//language_def("et_EE", "Eesti"),
 	language_def("en_GB", "English [GB]"),
 	language_def("C",     "English [US]"),
 	language_def("es_ES", "Español"),
-	language_def("eu_ES", "Euskera"),
+	//language_def("eu_ES", "Euskera"),
 	language_def("fr_FR", "Français"),
 	language_def("it_IT", "Italiano"),
 	language_def("la_IT", "Latina"),
 	language_def("hu_HU", "Magyar"),
 	language_def("nl_NL", "Nederlands"),
 	language_def("ja_JP", "日本語 (Nihongo)"),
-	language_def("no_NO", "Norsk"),
-	language_def("pl_PL", "Polski"),
-	language_def("pt_BR", "Português do Brasil"),
+	//language_def("no_NO", "Norsk"),
+        //language_def("oc_FR", "Occitan"),
+	//language_def("pl_PL", "Polski"),
+	//language_def("pt_BR", "Português do Brasil"),
 	language_def("ru_RU", "Русский (Russkij)"),
 	language_def("sk_SK", "Slovenčina"),
-	language_def("sl_SI", "Slovenščina"),
-	language_def("sr_CS", "Srpski"),
+	//language_def("sl_SI", "Slovenščina"),
+	//language_def("sr_CS", "Srpski"),
 	language_def("tr_TR", "Türkçe"),
 	language_def("fi_FI", "Suomi"),
 	language_def("sv_SE", "Svenska"),
-	language_def("zh_CN", "中文 (Zhongwen)"),
+	//language_def("zh_CN", "中文 (Zhongwen)"),
 
 	// end of list marker, do not remove
 	language_def("", "")
@@ -124,6 +126,15 @@ std::vector<language_def> get_languages()
 static void wesnoth_setlocale(int category, std::string const &slocale)
 {
 	char const *locale = slocale.c_str();
+	// FIXME: ideally we should check LANGUAGE and on first invocation
+	// use that value, so someone with es would get the game in Spanish
+	// instead of en_US the first time round
+	// LANGUAGE overrides other settings, so for now just get rid of it
+	// does Windows have unsetenv? if so, can make this unconditional
+#ifndef _WIN32
+	unsetenv ("LANGUAGE"); // void so no return value to check
+#endif
+
 #ifdef __BEOS__
 	if(setenv ("LANG", locale, 1) == -1)
 		std::cerr << "setenv LANG failed: " << strerror(errno);
@@ -167,6 +178,8 @@ static void wesnoth_setlocale(int category, std::string const &slocale)
 	if (res == NULL)
 		std::cerr << "WARNING: setlocale() failed for "
 			  << locale << ".\n";
+	else
+		std::cerr << "set locale to " << locale << "\n";
 }
 
 bool set_language(const language_def& locale)
