@@ -1,4 +1,4 @@
-/* $Id: multiplayer.cpp,v 1.160 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: multiplayer.cpp 8172 2005-09-06 13:53:14Z ott $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -343,10 +343,34 @@ void enter_lobby_mode(display& disp, const config& game_config, game_data& data,
 
 		switch (res) {
 		case mp::ui::JOIN:
-			enter_wait_mode(disp, game_config, data, chat, gamelist, false);
+			try {
+				enter_wait_mode(disp, game_config, data, chat, gamelist, false);
+			} catch(network::error& error) {
+				if(!error.message.empty()) {
+					if(error.message == _("No multiplayer sides available in this game") ||
+					   error.message == _("Era not available") ||
+					   error.message == _("No multiplayer sides found")) {
+						gui::show_error_message(disp, error.message);
+						break;
+					}
+				}
+				throw error;
+			}
 			break;
 		case mp::ui::OBSERVE:
-			enter_wait_mode(disp, game_config, data, chat, gamelist, true);
+			try {
+				enter_wait_mode(disp, game_config, data, chat, gamelist, true);
+			} catch(network::error& error) {
+				if(!error.message.empty()) {
+					if(error.message == _("No multiplayer sides available in this game") ||
+					   error.message == _("Era not available") ||
+					   error.message == _("No multiplayer sides found")) {
+						gui::show_error_message(disp, error.message);
+						break;
+					}
+				}
+				throw error;
+			}
 			break;
 		case mp::ui::CREATE:
 			try {
