@@ -1,4 +1,4 @@
-/* $Id: multiplayer_connect.cpp,v 1.151 2005/06/26 20:10:08 ott Exp $ */
+/* $Id: multiplayer_connect.cpp 8211 2005-09-12 02:20:28Z j_daniel $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -336,11 +336,18 @@ config connect::side::get_config() const
 		res["colour"] = lexical_cast<std::string>(colour_ + 1);
 		res["gold"] = lexical_cast<std::string>(gold_);
 
-		res["fog"] = parent_->params_.fog_game ? "yes" : "no";
-		res["shroud"] = parent_->params_.shroud_game ? "yes" : "no";
+		if(!parent_->params_.use_map_settings || res["fog"].empty() || (res["fog"] != "yes" && res["fog"] != "no")) {
+			res["fog"] = parent_->params_.fog_game ? "yes" : "no";
+		}
+
+		if(!parent_->params_.use_map_settings || res["shroud"].empty() || (res["shroud"] != "yes" && res["shroud"] != "no")) {
+			res["shroud"] = parent_->params_.shroud_game ? "yes" : "no";
+		}
+
 		res["share_maps"] = parent_->params_.share_maps ? "yes" : "no";
 		res["share_view"] =  parent_->params_.share_view ? "yes" : "no";
-		res["village_gold"] = lexical_cast<std::string>(parent_->params_.village_gold);
+		if(!parent_->params_.use_map_settings || res["village_gold"].empty())
+			res["village_gold"] = lexical_cast<std::string>(parent_->params_.village_gold);
 
 		res["allow_changes"] = "yes";
 	} else {
@@ -638,7 +645,7 @@ void connect::process_network_data(const config& data, const network::connection
 		const int side_drop = lexical_cast_default<int>(data["side_drop"], 0) - 1;
 		if(side_drop >= 0 && side_drop < int(sides_.size())) {
 			connected_user_list::iterator player = find_player(sides_[side_drop].get_id());
-			sides_[side_drop].reset(default_controller_);
+			sides_[side_drop].reset(sides_[side_drop].get_controller());
 			if (player != users_.end()) {
 				users_.erase(player);
 				update_user_combos();
@@ -678,6 +685,13 @@ void connect::process_network_data(const config& data, const network::connection
 					config response;
 					response.values["failed"] = "yes";
 					network::send_data(response, sock);
+					config kick;
+					kick["username"] = data["name"];
+					config res;
+					res.add_child("kick", kick);
+					network::send_data(res);
+					update_user_combos();
+					update_and_send_diff();
 					return;
 				}
 			}
@@ -822,16 +836,39 @@ void connect::lists_init()
 
 	//Teams
 	config::child_iterator sd;
-	for(sd = sides.first; sd != sides.second; ++sd) {
-		const int side_num = sd - sides.first + 1;
-		t_string& team_name = (**sd)["team_name"];
-		if(team_name.empty()) {
-			team_name = lexical_cast<std::string>(side_num);
+	if(params_.use_map_settings) {
+		for(sd = sides.first; sd != sides.second; ++sd) {
+			const int side_num = sd - sides.first + 1;
+			t_string& team_name = (**sd)["team_name"];
+
+			if(team_name.empty())
+				team_name = lexical_cast<std::string>(side_num);
+
+			std::vector<std::string>::const_iterator itor = std::find(team_names_.begin(), team_names_.end(), team_name);
+			if(itor == team_names_.end()) {
+				team_names_.push_back(team_name);
+				player_teams_.push_back(team_prefix_ + team_name.str());
+			}
 		}
-		std::vector<std::string>::const_iterator itor = std::find(team_names_.begin(), team_names_.end(), team_name);
-		if(itor == team_names_.end()) {
-			team_names_.push_back(team_name);
-			player_teams_.push_back(team_prefix_ + team_name.str());
+	} else {
+		std::vector<std::string> team_names;
+		for(sd = sides.first; sd != sides.second; ++sd) {
+			const std::string side_num = lexical_cast<std::string>(sd - sides.first + 1);
+			t_string& team_name = (**sd)["team_name"];
+
+			if(team_name.empty())
+				team_name = side_num;
+
+			std::vector<std::string>::const_iterator itor = std::find(team_names.begin(), team_names.end(), team_name);
+			if(itor == team_names.end()) {
+				team_names.push_back(team_name);
+				team_name = lexical_cast<std::string>(team_names.size());
+			} else {
+				team_name = lexical_cast<std::string>(itor - team_names.begin() + 1);
+			}
+
+			team_names_.push_back(side_num);
+			player_teams_.push_back(team_prefix_ + side_num);
 		}
 	}
 
@@ -867,7 +904,10 @@ void connect::load_game()
 		}
 
 		std::string error_log;
-		::load_game(game_data_, game, state_, &error_log);
+		{
+			cursor::setter cur(cursor::WAIT);
+			::load_game(game_data_, game, state_, &error_log);
+		}
 		if(!error_log.empty()) {
 			gui::show_error_message(disp(),
 					_("The file you have tried to load is corrupt: '") +
@@ -925,6 +965,10 @@ void connect::load_game()
 		level_.add_child("era", *era_cfg);
 		level_["experience_modifier"] = lexical_cast<std::string>(params_.xp_modifier);
 	}
+	level_["mp_village_gold"] = lexical_cast<std::string>(params_.village_gold);
+	level_["mp_use_map_settings"] = params_.use_map_settings ? "yes" : "no";
+	level_["mp_fog"] = params_.fog_game ? "yes" : "no";
+	level_["mp_shroud"] = params_.shroud_game ? "yes" : "no";
 
 	//this will force connecting clients to be using the same version number as us.
 	level_["version"] = game_config::version;
