@@ -1,6 +1,6 @@
-/* $Id: multiplayer_connect.hpp,v 1.36 2005/04/02 10:36:12 gruikya Exp $ */
+/* $Id: multiplayer_connect.hpp 7120 2005-06-04 19:16:06Z ott $ */
 /*
-   Copyright (C) 
+   Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
 
    This program is free software; you can redistribute it and/or modify
@@ -25,8 +25,6 @@
 
 namespace mp {
 
-enum controller { CNTR_NETWORK = 0, CNTR_LOCAL, CNTR_COMPUTER, CNTR_EMPTY, CNTR_LAST };
-
 class connect : public mp::ui
 {
 public:
@@ -94,7 +92,7 @@ public:
 
 		// The mp::connect widget owning this mp::connect::side. Used
 		// in the constructor, must be first.
-		connect* parent_; 
+		connect* parent_;
 
 		config cfg_;
 
@@ -131,18 +129,20 @@ public:
 	typedef std::vector<side> side_list;
 
 
-	connect(display& disp, const config& game_config, const game_data& data, 
-			chat& c, config& gamelist, const create::parameters& params, 
+	connect(display& disp, const config& game_config, const game_data& data,
+			chat& c, config& gamelist, const create::parameters& params,
 			mp::controller default_controller);
 
 	virtual void process_event();
 
-	// Returns the level data useful to play the game
-	const config& get_level();
+	/** Returns the game state, which contains all information about the
+	 * current scenario.
+	 */
 	const game_state& get_state();
 
-	// Updates the current level, resolves random factions, and sends a
-	// "start game" message to the network, with the current level
+	/** Updates the current game state, resolves random factions, and sends
+	 * a "start game" message to the network.
+	 */
 	void start_game();
 
 protected:
@@ -164,13 +164,13 @@ private:
 
 	// Updates the level_ variable to reflect the sides in the sides_ vector
 	void update_level();
-	
+
 	// Updates the level, and send a diff to the clients
 	void update_and_send_diff();
 
 	// Returns true if there still are sides available for this game
 	bool sides_available();
-	
+
 	// Updates the state of the player list, the launch button and of the
 	// start game label, to reflect the actual state.
 	void update_playerlist_state(bool silent=true);
@@ -190,16 +190,13 @@ private:
 	// This is the main, and global, game data.
 	const game_data& game_data_;
 
-	// This is the configuration object which represents the level which
-	// will be generated by configuring this multiplayer game.
 	config level_;
 
-	create::parameters params_;
-
-	// This is the "game state" object, which is constructed along with the
-	// "level" object
+	// This is the "game state" object which is created by this dialog.
 	game_state state_;
 
+	create::parameters params_;
+
 	// The list of available sides for the current era
 	config::child_list era_sides_;
 
@@ -212,7 +209,7 @@ private:
 	// team_name list and "Team" prefix
 	std::vector<std::string> team_names_;
 	const std::string team_prefix_;
-	
+
 	side_list sides_;
 	connected_user_list users_;
 
