@@ -1,4 +1,4 @@
-/* $Id: multiplayer_create.cpp,v 1.27 2005/06/06 20:12:47 gruikya Exp $ */
+/* $Id: multiplayer_create.cpp 8269 2005-09-17 15:06:28Z ott $ */
 /*
    Copyright (C)
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -13,6 +13,8 @@
 
 #include "global.hpp"
 
+#include <memory>
+
 #include "display.hpp"
 #include "gettext.hpp"
 #include "image.hpp"
@@ -20,6 +22,7 @@
 #include "map_create.hpp"
 #include "multiplayer_create.hpp"
 #include "filesystem.hpp"
+#include "log.hpp"
 #include "preferences.hpp"
 #include "video.hpp"
 #include "serialization/string_utils.hpp"
@@ -43,10 +46,11 @@ create::create(display& disp, const config &cfg, chat& c, config& gamelist) :
 	village_gold_label_(disp.video(), "", font::SIZE_SMALL, font::LOBBY_COLOUR),
 	xp_modifier_slider_(disp.video()),
 	xp_modifier_label_(disp.video(), "", font::SIZE_SMALL, font::LOBBY_COLOUR),
-	name_entry_label_(disp.video(), _("Name of game:"), font::SIZE_SMALL, font::LOBBY_COLOUR),
+	name_entry_label_(disp.video(), _("Name of game:"), font::SIZE_PLUS, font::LOBBY_COLOUR),
 	num_players_label_(disp.video(), "", font::SIZE_SMALL, font::LOBBY_COLOUR),
 	era_label_(disp.video(), _("Era:"), font::SIZE_SMALL, font::LOBBY_COLOUR),
 	map_label_(disp.video(), _("Map to play:"), font::SIZE_SMALL, font::LOBBY_COLOUR),
+	use_map_settings_(disp.video(), _("Use map settings"), gui::button::TYPE_CHECK),
 	fog_game_(disp.video(), _("Fog Of War"), gui::button::TYPE_CHECK),
 	shroud_game_(disp.video(), _("Shroud"), gui::button::TYPE_CHECK),
 	observers_game_(disp.video(), _("Observers"), gui::button::TYPE_CHECK),
@@ -94,6 +98,9 @@ create::create(display& disp, const config &cfg, chat& c, config& gamelist) :
 	xp_modifier_slider_.set_increment(10);
 	xp_modifier_slider_.set_help_string(_("The amount of experience a unit needs to advance"));
 
+	use_map_settings_.set_check(preferences::use_map_settings());
+	use_map_settings_.set_help_string(_("Use scenario specific settings"));
+
 	fog_game_.set_check(preferences::fog());
 	fog_game_.set_help_string(_("Enemy units cannot be seen unless they are in range of your units"));
 
@@ -144,6 +151,7 @@ create::~create()
 
 	//Save values for next game
 	preferences::set_allow_observers(parameters_.allow_observers);
+	preferences::set_use_map_settings(parameters_.use_map_settings);
 	preferences::set_fog(parameters_.fog_game);
 	preferences::set_shroud(parameters_.shroud_game);
 	preferences::set_turns(parameters_.num_turns);
@@ -170,6 +178,7 @@ create::parameters& create::get_parameters()
 	parameters_.num_turns = turns;
 	parameters_.village_gold = village_gold_slider_.value();
 	parameters_.xp_modifier = xp_modifier_slider_.value();
+	parameters_.use_map_settings = use_map_settings_.checked();
 	parameters_.fog_game = fog_game_.checked();
 	parameters_.shroud_game = shroud_game_.checked();
 	parameters_.allow_observers = observers_game_.checked();
@@ -281,6 +290,7 @@ void create::process_event()
 		const cursor::setter cursor_setter(cursor::WAIT);
 
 		//generate the random map
+		cursor::setter cur(cursor::WAIT);
 		parameters_.scenario_data = generator_->create_scenario(std::vector<std::string>());
 		map_changed = true;
 
@@ -293,11 +303,21 @@ void create::process_event()
 		regenerate_map_.hide(generator_ == NULL);
 
 		const std::string& map_data = parameters_.scenario_data["map_data"];
-		gamemap map(game_config(), map_data);
+
+		std::auto_ptr<gamemap> map(NULL);
+		try {
+			map.reset(new gamemap(game_config(), map_data));
+		} catch(gamemap::incorrect_format_exception& e) {
+			LOG_STREAM(err,general) << "map could not be loaded: " << e.msg_ << "\n";
+			tooltips::clear_tooltips(minimap_rect_);
+			tooltips::add_tooltip(minimap_rect_,e.msg_);
+		}
+
+		launch_game_.enable(map.get() != NULL);
 
 		//if there are less sides in the configuration than there are starting
 		//positions, then generate the additional sides
-		const int map_positions = map.num_valid_starting_positions();
+		const int map_positions = map.get() != NULL ? map->num_valid_starting_positions() : 0;
 
 		for(int pos =  parameters_.scenario_data.get_children("side").size(); pos < map_positions; ++pos) {
 			config& side = parameters_.scenario_data.add_child("side");
@@ -314,16 +334,31 @@ void create::process_event()
 					  parameters_.scenario_data.get_children("side").size()-1);
 		}
 
-		const surface mini(image::getMinimap(minimap_rect_.w,minimap_rect_.h,map,0));
-		if(mini != NULL) {
-			SDL_Rect rect = minimap_rect_;
-			SDL_BlitSurface(mini, NULL, video().getSurface(), &rect);
-			update_rect(rect);
+		if(map.get() != NULL) {
+			const surface mini(image::getMinimap(minimap_rect_.w,minimap_rect_.h,*map,0));
+			if(mini != NULL) {
+				SDL_Rect rect = minimap_rect_;
+				SDL_BlitSurface(mini, NULL, video().getSurface(), &rect);
+				update_rect(rect);
+			}
 		}
+
 		const int nsides = parameters_.scenario_data.get_children("side").size();
 		std::stringstream players;
-		players << _("Players: ") << nsides;
+		if(map.get() != NULL) {
+			players << _("Players: ") << nsides;
+		} else {
+			players << _("Error");
+		}
 		num_players_label_.set_text(players.str());
+
+		if(use_map_settings_.checked()) {
+			try {
+				xp_modifier_slider_.set_value(lexical_cast<int>(parameters_.scenario_data["experience_modifier"]));
+			} catch(bad_lexical_cast&) {
+				xp_modifier_slider_.set_value(preferences::xp_modifier());
+			}
+		}
 	}
 }
 
@@ -344,6 +379,7 @@ void create::hide_children(bool hide)
 	era_label_.hide(hide);
 	map_label_.hide(hide);
 
+	use_map_settings_.hide(hide);
 	fog_game_.hide(hide);
 	shroud_game_.hide(hide);
 	observers_game_.hide(hide);
@@ -362,13 +398,19 @@ void create::hide_children(bool hide)
 		minimap_restorer_.assign(new surface_restorer(&video(), minimap_rect_));
 
 		const std::string& map_data = parameters_.scenario_data["map_data"];
-		gamemap map(game_config(), map_data);
-		const surface mini(image::getMinimap(minimap_rect_.w,minimap_rect_.h,map,0));
-		if(mini != NULL) {
-			SDL_Rect rect = minimap_rect_;
-			SDL_BlitSurface(mini, NULL, video().getSurface(), &rect);
-			update_rect(rect);
+
+		try {
+			gamemap map(game_config(), map_data);
+			const surface mini(image::getMinimap(minimap_rect_.w,minimap_rect_.h,map,0));
+			if(mini != NULL) {
+				SDL_Rect rect = minimap_rect_;
+				SDL_BlitSurface(mini, NULL, video().getSurface(), &rect);
+				update_rect(rect);
+			}
+		} catch(gamemap::incorrect_format_exception& e) {
+			LOG_STREAM(err,general) << "map could not be loaded: " << e.msg_ << "\n";
 		}
+
 	}
 }
 
@@ -387,10 +429,9 @@ void create::layout_children(const SDL_Rect& rect)
 
 	// Name Entry
 	name_entry_label_.set_location(xpos, ypos);
-	ypos += name_entry_label_.height() + border_size;
-	name_entry_.set_location(xpos, ypos);
-	name_entry_.set_width(ca.w);
-	ypos += name_entry_.height() + border_size;
+	name_entry_.set_location(xpos + name_entry_label_.width() + border_size, ypos);
+	name_entry_.set_width(ca.w - name_entry_label_.width() - border_size);
+	ypos += maximum<int>(name_entry_.height(), name_entry_label_.height()) + border_size;
 
 	// Save ypos here (column top)
 	int ypos_columntop = ypos;
@@ -404,9 +445,14 @@ void create::layout_children(const SDL_Rect& rect)
 	num_players_label_.set_location(xpos, ypos);
 	ypos += num_players_label_.height() + border_size;
 
-	regenerate_map_.set_location(xpos, ypos);
+	regenerate_map_.set_location(xpos + era_label_.width() + border_size, ypos);
 	ypos += regenerate_map_.height() + border_size;
-	generator_settings_.set_location(xpos, ypos);
+	generator_settings_.set_location(xpos + era_label_.width() + border_size, ypos);
+	ypos += generator_settings_.height() + border_size;
+
+	era_label_.set_location(xpos, ypos + (era_combo_.height() - era_label_.height()) / 2);
+	era_combo_.set_location(xpos + era_label_.width() + border_size, ypos);
+	ypos += era_combo_.height() + border_size;
 
 	// Second column: map menu
 	ypos = ypos_columntop;
@@ -443,9 +489,9 @@ void create::layout_children(const SDL_Rect& rect)
 	xp_modifier_slider_.set_location(xpos, ypos);
 	ypos += xp_modifier_slider_.height() + border_size;
 
-	era_label_.set_location(xpos, ypos + (era_combo_.height() - era_label_.height()) / 2);
-	era_combo_.set_location(xpos + era_label_.width() + border_size, ypos);
-	ypos += era_combo_.height() + border_size;
+
+	use_map_settings_.set_location(xpos, ypos);
+	ypos += use_map_settings_.height() + border_size;
 
 	fog_game_.set_location(xpos, ypos);
 	ypos += fog_game_.height() + border_size;
