@@ -1,4 +1,4 @@
-/* $Id: multiplayer_ui.cpp,v 1.28 2005/06/06 20:12:47 gruikya Exp $ */
+/* $Id: multiplayer_ui.cpp 8137 2005-09-04 09:55:05Z ettin $ */
 /*
    Copyright (C) 2005
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -166,6 +166,8 @@ ui::ui(display& disp, const std::string& title, const config& cfg, chat& c, conf
 
 	result_(CONTINUE)
 {
+	const SDL_Rect area = { 0, 0, disp.video().getx(), disp.video().gety() };
+	set_location(area);
 }
 
 void ui::process_network()
@@ -350,8 +352,9 @@ void ui::hide_children(bool hide)
 
 void ui::layout_children(const SDL_Rect& rect)
 {
-	title_.set_location(xscale(11)+4, xscale(42) + 4);
+	title_.set_location(xscale(12) + 8, yscale(38) + 8);
 	users_menu_.set_width(xscale(159));
+	users_menu_.set_max_width(xscale(159));
 	users_menu_.set_location(xscale(856), yscale(42));
 	users_menu_.set_height(yscale(715));
 	users_menu_.set_max_height(yscale(715));
@@ -375,19 +378,17 @@ void ui::gamelist_updated(bool silent)
 
 void ui::set_user_list(const std::vector<std::string>& list, bool silent)
 {
-	const int old_users = user_list_.size();
-	user_list_ = list;
-	const int new_users = user_list_.size();
-
 	if(!silent) {
-		if(new_users < old_users) {
+		if(list.size() < user_list_.size()) {
 			sound::play_sound(game_config::sounds::user_leave);
-		} else if(new_users > old_users) {
+		} else if(list.size() > user_list_.size()) {
 			sound::play_sound(game_config::sounds::user_arrive);
 		}
 	}
 
-	users_menu_.set_items(user_list_);
+	user_list_ = list;
+
+	users_menu_.set_items(user_list_,true,true);
 }
 
 const gui::widget& ui::title() const
