@@ -1,3 +1,16 @@
+/* $Id: network.cpp 7938 2005-08-20 19:12:01Z j_daniel $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #include "global.hpp"
 
 #include "serialization/binary_wml.hpp"
@@ -20,6 +33,18 @@
 #include <vector>
 
 #include <signal.h>
+#if defined(_WIN32) || defined(__WIN32__) || defined (WIN32)
+#include <windows.h>
+#else
+#include <sys/types.h>
+#include <sys/socket.h>
+#ifdef __BEOS__
+#include <socket.h>
+#else
+#include <fcntl.h>
+#endif
+#define SOCKET int
+#endif
 
 #define LOG_NW LOG_STREAM(info, network)
 #define WRN_NW LOG_STREAM(warn, network)
@@ -96,7 +121,7 @@ void check_error()
 	if(sock) {
 		for(connection_map::const_iterator i = connections.begin(); i != connections.end(); ++i) {
 			if(i->second.sock == sock) {
-				throw network::error(_("Socket error"),i->first);
+				throw network::error(_("Client disconnected"),i->first);
 			}
 		}
 	}
@@ -174,7 +199,7 @@ manager::manager(size_t nthreads) : free_(true)
 		throw error(SDL_GetError());
 	}
 
-	socket_set = SDLNet_AllocSocketSet(64);
+	socket_set = SDLNet_AllocSocketSet(512);
 
 	worker_pool_man = new network_worker_pool::manager(nthreads);
 }
@@ -260,6 +285,16 @@ void connect_operation::check_error()
 	}
 }
 
+namespace {
+	struct _TCPsocket {
+		int ready;
+		SOCKET channel;
+		IPaddress remoteAddress;
+		IPaddress localAddress;
+		int sflag;
+	};
+}
+
 void connect_operation::run()
 {
 	char* const hostname = host_.empty() ? NULL : const_cast<char*>(host_.c_str());
@@ -276,6 +311,34 @@ void connect_operation::run()
 		return;
 	}
 
+// use non blocking IO
+#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32)
+	{
+		unsigned long mode = 1;
+		ioctlsocket (((_TCPsocket*)sock)->channel, FIONBIO, &mode);
+	}
+#elif !defined(__BEOS__)
+	int flags;
+	flags = fcntl(((_TCPsocket*)sock)->channel, F_GETFL, 0);
+#if defined(O_NONBLOCK)
+	flags |= O_NONBLOCK;
+#elif defined(O_NDELAY)
+	flags |= O_NDELAY;
+#elif defined(FNDELAY)
+	flags |= FNDELAY;
+#endif
+	if(fcntl(((_TCPsocket*)sock)->channel, F_SETFL, flags) == -1) {
+		error_ = ("Could not make socket non-blocking: " + std::string(strerror(errno))).c_str();
+		return;
+	}
+#else
+	int on = 1;
+	if(setsockopt(((_TCPsocket*)sock)->channel, SOL_SOCKET, SO_NONBLOCK, &on, sizeof(int)) < 0) {
+		error_ = ("Could not make socket non-blocking: " + std::string(strerror(errno))).c_str();
+		return;
+	}
+#endif
+
 	//if this is a server socket
 	if(hostname == NULL) {
 		const threading::lock l(get_mutex());
@@ -289,7 +352,6 @@ void connect_operation::run()
 	const int nbytes = SDLNet_TCP_Send(sock,buf,4);
 	if(nbytes != 4) {
 		SDLNet_TCP_Close(sock);
-
 		error_ = "Could not send initial handshake";
 		return;
 	}
@@ -320,7 +382,7 @@ void connect_operation::run()
 	wassert(schemas.count(connect_) == 0);
 	schemas.insert(std::pair<network::connection,schema_pair>(connect_,schema_pair()));
 
-	notify_finished();
+	while(!notify_finished());
 }
 
 }
@@ -365,7 +427,7 @@ connection accept_connection()
 		LOG_NW << "received connection. Pending handshake...\n";
 		pending_sockets.push_back(sock);
 		if(pending_socket_set == 0) {
-			pending_socket_set = SDLNet_AllocSocketSet(64);
+			pending_socket_set = SDLNet_AllocSocketSet(512);
 		}
 
 		if(pending_socket_set != 0) {
@@ -691,9 +753,13 @@ std::string ip_address(connection connection_num)
 	return str.str();
 }
 
-std::pair<int,int> current_transfer_stats()
+statistics get_send_stats(connection handle)
 {
-	return network_worker_pool::get_current_transfer_stats();
+	return network_worker_pool::get_current_transfer_stats(handle == 0 ? get_socket(sockets.back()) : get_socket(handle)).first;
+}
+statistics get_receive_stats(connection handle)
+{
+	return network_worker_pool::get_current_transfer_stats(handle == 0 ? get_socket(sockets.back()) : get_socket(handle)).second;
 }
 
 } //end namespace network
