@@ -1,6 +1,6 @@
-/* $Id: playlevel.cpp,v 1.209 2005/06/18 22:13:09 Sirp Exp $ */
+/* $Id: playlevel.cpp 8300 2005-09-18 22:38:06Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -112,7 +112,7 @@ namespace {
 	bool is_observer(const std::vector<team>& teams)
 	{
 		for(std::vector<team>::const_iterator i = teams.begin(); i != teams.end(); ++i) {
-			if(i->is_human()) {
+			if(i->is_human() || i->is_persistent()) {
 				return false;
 			}
 		}
@@ -241,7 +241,8 @@ LEVEL_RESULT play_level(const game_data& gameinfo, const config& game_config,
 
 		LOG_NG << "initializing team...\n";
 
-		if ((**ui)["controller"] == preferences::client_type() && (**ui)["description"] == preferences::login()) {
+		const std::string& controller = (**ui)["controller"];
+		if (controller == preferences::client_type() && (**ui)["description"] == preferences::login()) {
 			first_human_team = ui - unit_cfg.begin();
 		} else if(first_human_team == -1 && ((**ui)["controller"] == "human" || (**ui)["persistent"] == "1")) {
 			first_human_team = ui - unit_cfg.begin();
@@ -312,8 +313,9 @@ LEVEL_RESULT play_level(const game_data& gameinfo, const config& game_config,
 			}
 
 			if(start_pos.valid()) {
+				new_unit.new_turn();
 				units.insert(std::pair<gamemap::location,unit>(
-								map.starting_position(new_unit.side()), new_unit));
+							map.starting_position(new_unit.side()), new_unit));
 			}
 		}
 
@@ -473,6 +475,13 @@ LEVEL_RESULT play_level(const game_data& gameinfo, const config& game_config,
 		//instead of starting a fresh one
 		const bool loading_game = lvl["playing_team"].empty() == false;
 
+		//pre-start events must be executed before any GUI operation,
+		//as those may cause the display to be refreshed.
+		if(!loading_game) {
+			update_locker lock_display(gui.video());
+			game_events::fire("prestart");
+		}
+
 		gui.begin_game();
 		gui.adjust_colours(0,0,0);
 
@@ -493,9 +502,6 @@ LEVEL_RESULT play_level(const game_data& gameinfo, const config& game_config,
 			first_player = 0;
 		}
 
-		if(!loading_game) {
-			game_events::fire("prestart");
-		}
 		for(std::vector<team>::iterator t = teams.begin(); t != teams.end(); ++t) {
 			clear_shroud(gui,status,map,gameinfo,units,teams,(t-teams.begin()));
 		}
@@ -767,11 +773,9 @@ redo_turn:
 			}
 
 			if (!obs)
-				gui::show_dialog(gui, NULL,
-				                 _("Defeat"),
-				                 _("You have been defeated!"),
-				                 gui::OK_ONLY);
-			return DEFEAT;
+				return DEFEAT;
+			else
+				return QUIT;
 		} else if (end_level.result == VICTORY || end_level.result == LEVEL_CONTINUE ||
 		           end_level.result == LEVEL_CONTINUE_NO_SAVE) {
 			try {
