@@ -1,6 +1,6 @@
-/* $Id: playturn.cpp,v 1.383 2005/06/21 22:19:19 ydirson Exp $ */
+/* $Id: playturn.cpp 8172 2005-09-06 13:53:14Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -152,8 +152,10 @@ turn_info::turn_info(const game_data& gameinfo, game_state& state_of_game,
     key_(key), gui_(gui), map_(map), teams_(teams), team_num_(team_num),
     units_(units), browse_(mode != PLAY_TURN), allow_network_commands_(mode == BROWSE_NETWORKED),
     left_button_(false), right_button_(false), middle_button_(false),
-	minimap_scrolling_(false), enemy_paths_(false), last_nearest_(gamemap::location::NORTH), last_second_nearest_(gamemap::location::NORTH),
-    path_turns_(0), end_turn_(false), start_ncmd_(-1), textbox_(textbox), replay_sender_(replay_sender)
+	minimap_scrolling_(false), enemy_paths_(false),
+	last_nearest_(gamemap::location::NORTH),
+	last_second_nearest_(gamemap::location::NORTH),
+	path_turns_(0), end_turn_(false), start_ncmd_(-1), textbox_(textbox), replay_sender_(replay_sender)
 {
 	enemies_visible_ = enemies_visible();
 
@@ -164,6 +166,11 @@ void turn_info::turn_slice()
 {
 	events::pump();
 	events::raise_process_event();
+
+	if (gui_.video().modeChanged()) {
+		update_textbox_location();
+	}
+
 	events::raise_draw_event();
 
 	const theme::menu* const m = gui_.menu_pressed();
@@ -305,7 +312,8 @@ void turn_info::mouse_motion(int x, int y)
 		if(minimap_scrolling_) return;
 	}
 
-	gamemap::location::DIRECTION nearest_hex, second_nearest_hex;
+	gamemap::location::DIRECTION nearest_hex = gamemap::location::NDIRECTIONS;
+	gamemap::location::DIRECTION second_nearest_hex = gamemap::location::NDIRECTIONS;
 	const team& current_team = teams_[team_num_-1];
 	const gamemap::location new_hex = gui_.hex_clicked_on(x,y,&nearest_hex,&second_nearest_hex);
 
@@ -1020,10 +1028,16 @@ bool turn_info::in_context_menu(hotkey::HOTKEY_COMMAND command) const
 	//Only display these if the mouse is over a castle or keep tile
 	case hotkey::HOTKEY_RECRUIT:
 	case hotkey::HOTKEY_REPEAT_RECRUIT:
-	case hotkey::HOTKEY_RECALL:
+	case hotkey::HOTKEY_RECALL: {
 		// last_hex_ is set by turn_info::mouse_motion
 		// Enable recruit/recall on castle/keep tiles
-		return map_.is_castle(last_hex_);
+		const unit_map::const_iterator leader = team_leader(team_num_,units_);
+		if (leader != units_.end()) {
+			return can_recruit_on(map_, leader->first, last_hex_);
+		} else {
+			return false;
+		}
+	}
 	default:
 		return true;
 	}
@@ -1290,26 +1304,27 @@ void turn_info::end_turn()
 	if(browse_)
 		return;
 
-	bool unmoved_units = false, partmoved_units = false;
+	bool unmoved_units = false, partmoved_units = false, some_units_have_moved = false;
 	for(unit_map::const_iterator un = units_.begin(); un != units_.end(); ++un) {
 		if(un->second.side() == team_num_) {
 			if(unit_can_move(un->first,units_,map_,teams_)) {
-				if(un->second.movement_left() == un->second.total_movement()) {
+				if(!un->second.has_moved()) {
 					unmoved_units = true;
 				}
 
 				partmoved_units = true;
 			}
+			if(un->second.has_moved() && ! un->second.has_goto()) {
+				some_units_have_moved = true;
+			}
 		}
 	}
 
 	//Ask for confirmation if the player hasn't made any moves (other than gotos).
-	if(preferences::confirm_no_moves() && unmoved_units) {
-		if (recorder.ncommands() == start_ncmd_) {
-			const int res = gui::show_dialog(gui_,NULL,"",_("You have not started your turn yet.  Do you really want to end your turn?"), gui::YES_NO);
-			if(res != 0) {
-				return;
-			}
+	if(preferences::confirm_no_moves() && ! some_units_have_moved) {
+		const int res = gui::show_dialog(gui_,NULL,"",_("You have not started your turn yet. Do you really want to end your turn?"), gui::YES_NO);
+		if(res != 0) {
+			return;
 		}
 	}
 
@@ -1939,19 +1954,19 @@ void turn_info::do_recruit(const std::string& name)
 		if(msg.empty()) {
 			current_team.spend_gold(u_type->second.cost());
 			statistics::recruit_unit(new_unit);
+
+			clear_undo_stack();
+			redo_stack_.clear();
+
+			clear_shroud();
+
+			gui_.recalculate_minimap();
+			gui_.invalidate_game_status();
+			gui_.invalidate_all();
 		} else {
 			recorder.undo();
 			gui::show_dialog(gui_,NULL,"",msg,gui::OK_ONLY);
 		}
-
-		clear_undo_stack();
-		redo_stack_.clear();
-
-		clear_shroud();
-
-		gui_.recalculate_minimap();
-		gui_.invalidate_game_status();
-		gui_.invalidate_all();
 	}
 }
 
@@ -2110,8 +2125,11 @@ void turn_info::recall()
 				undo_stack_.push_back(undo_action(un,loc,res));
 				redo_stack_.clear();
 
+				clear_shroud();
+
 				recall_list.erase(recall_list.begin()+res);
 				gui_.invalidate_game_status();
+				gui_.invalidate_all();
 			}
 		}
 	}
@@ -2856,27 +2874,25 @@ turn_info::PROCESS_DATA_RESULT turn_info::process_network_data(const config& cfg
 	return turn_end ? PROCESS_END_TURN : PROCESS_CONTINUE;
 }
 
-void turn_info::create_textbox(floating_textbox::MODE mode, const std::string& label, const std::string& check_label, bool checked)
+void turn_info::update_textbox_location()
 {
-	close_textbox();
-
-	textbox_.mode = mode;
-
-	if(check_label != "") {
-		textbox_.check.assign(new gui::button(gui_.video(),check_label,gui::button::TYPE_CHECK));
-		textbox_.check->set_check(checked);
-	}
+	if (textbox_.box == NULL)
+		return;
 
 	const SDL_Rect& area = gui_.map_area();
 
 	const int border_size = 10;
 
 	const int ypos = area.y+area.h-30 - (textbox_.check != NULL ? textbox_.check->height() + border_size : 0);
-	textbox_.label = font::add_floating_label(label,font::SIZE_NORMAL,font::YELLOW_COLOUR,area.x+border_size,ypos,0,0,-1,
-		area,font::LEFT_ALIGN);
-	if(textbox_.label == 0) {
+
+	if (textbox_.label != 0)
+		font::remove_floating_label(textbox_.label);
+
+	textbox_.label = font::add_floating_label(textbox_.label_string,font::SIZE_NORMAL,
+			font::YELLOW_COLOUR,area.x+border_size,ypos,0,0,-1, area,font::LEFT_ALIGN);
+
+	if (textbox_.label == 0)
 		return;
-	}
 
 	const SDL_Rect& label_area = font::get_floating_label_rect(textbox_.label);
 	const int textbox_width = area.w - label_area.w - border_size*3;
@@ -2886,9 +2902,14 @@ void turn_info::create_textbox(floating_textbox::MODE mode, const std::string& l
 		return;
 	}
 
-	textbox_.box.assign(new gui::textbox(gui_.video(),textbox_width,"",true,256,0.8,0.6));
-	textbox_.box->set_volatile(true);
-	textbox_.box->set_location(area.x + label_area.w + border_size*2,ypos);
+	if(textbox_.box != NULL) {
+		textbox_.box->set_volatile(true);
+		const SDL_Rect rect = {
+			area.x + label_area.w + border_size*2, ypos,
+			textbox_width, textbox_.box->height()
+		};
+		textbox_.box->set_location(rect);
+	}
 
 	if(textbox_.check != NULL) {
 		textbox_.check->set_volatile(true);
@@ -2896,6 +2917,24 @@ void turn_info::create_textbox(floating_textbox::MODE mode, const std::string& l
 	}
 }
 
+void turn_info::create_textbox(floating_textbox::MODE mode, const std::string& label, const std::string& check_label, bool checked)
+{
+	close_textbox();
+
+	textbox_.label_string = label;
+	textbox_.mode = mode;
+
+	if(check_label != "") {
+		textbox_.check.assign(new gui::button(gui_.video(),check_label,gui::button::TYPE_CHECK));
+		textbox_.check->set_check(checked);
+	}
+
+
+	textbox_.box.assign(new gui::textbox(gui_.video(),100,"",true,256,0.8,0.6));
+
+	update_textbox_location();
+}
+
 void turn_info::close_textbox()
 {
 	if(textbox_.active() == false) {
