@@ -1,6 +1,6 @@
-/* $Id: playturn.hpp,v 1.69 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: playturn.hpp 8041 2005-08-27 22:52:54Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -69,6 +69,7 @@ public:
 		            TEXTBOX_COMMAND };
 		MODE mode;
 
+		std::string label_string;
 		int label;
 
 		floating_textbox() : box(NULL), check(NULL), mode(TEXTBOX_NONE), label(0)
@@ -248,6 +249,7 @@ private:
 
 	floating_textbox& textbox_;
 
+	void update_textbox_location();
 	void create_textbox(floating_textbox::MODE mode, const std::string& label, const std::string& check_label="", bool checked=false);
 	void close_textbox();
 	void enter_textbox();
