@@ -1,6 +1,6 @@
-/* $Id: preferences.cpp,v 1.160 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: preferences.cpp 7672 2005-08-01 17:07:06Z j_daniel $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -247,40 +247,24 @@ void set_language(const std::string& s)
 
 int music_volume()
 {
-	static const int default_value = 100;
-	const string_map::const_iterator volume = prefs.values.find("music_volume");
-	if(volume != prefs.values.end() && volume->second.empty() == false)
-		return atoi(volume->second.c_str());
-	else
-		return default_value;
+	return lexical_cast_default<int>(prefs["music_volume"], 100);
 }
 
 void set_music_volume(int vol)
 {
-	std::stringstream stream;
-	stream << vol;
-	prefs["music_volume"] = stream.str();
-
-	sound::set_music_volume(vol / 100.0);
+	prefs["music_volume"] = lexical_cast_default<std::string>(vol, "100");
+	sound::set_music_volume(music_volume());
 }
 
 int sound_volume()
 {
-	static const int default_value = 100;
-	const string_map::const_iterator volume = prefs.values.find("sound_volume");
-	if(volume != prefs.values.end() && volume->second.empty() == false)
-		return atoi(volume->second.c_str());
-	else
-		return default_value;
+	return lexical_cast_default<int>(prefs["sound_volume"], 100);
 }
 
 void set_sound_volume(int vol)
 {
-	std::stringstream stream;
-	stream << vol;
-	prefs["sound_volume"] = stream.str();
-
-	sound::set_sound_volume(vol / 100.0);
+	prefs["sound_volume"] = lexical_cast_default<std::string>(vol, "100");
+	sound::set_sound_volume(sound_volume());
 }
 
 void mute(bool muted)
@@ -464,6 +448,53 @@ void set_message_bell(bool ison)
 	prefs["message_bell"] = (ison ? "yes" : "no");
 }
 
+bool sound_on() {
+	return prefs["sound"] != "no";
+}
+
+bool set_sound(bool ison) {
+	if(!sound_on() && ison) {
+		prefs["sound"] = "yes";
+		if(!music_on()) {
+			if(!sound::init_sound()) {
+				prefs["sound"] = "no";
+				return false;
+			}
+		}
+	} else if(sound_on() && !ison) {
+		prefs["sound"] = "no";
+		sound::stop_sound();
+		if(!music_on())
+			sound::close_sound();
+	}
+	return true;
+}
+
+bool music_on() {
+	return prefs["music"] != "no";
+}
+
+bool set_music(bool ison) {
+	if(!music_on() && ison) {
+		prefs["music"] = "yes";
+		if(!sound_on()) {
+			if(!sound::init_sound()) {
+				prefs["music"] = "no";
+				return false;
+			}
+		}
+		else
+			sound::play_music("");
+	} else if(music_on() && !ison) {
+		prefs["music"] = "no";
+		if(!sound_on())
+			sound::close_sound();
+		else
+			sound::stop_music();
+	}
+	return true;
+}
+
 bool turn_dialog()
 {
 	return prefs["turn_dialog"] == "yes";
@@ -489,6 +520,16 @@ void set_allow_observers(bool value)
 	prefs["allow_observers"] = value ? "yes" : "no";
 }
 
+bool use_map_settings()
+{
+	return prefs["mp_use_map_settings"] == "yes";
+}
+
+void set_use_map_settings(bool value)
+{
+	prefs["mp_use_map_settings"] = value ? "yes" : "no";
+}
+
 bool fog()
 {
 	return prefs["mp_fog"] == "yes";
@@ -826,7 +867,7 @@ private:
 	            show_grid_button_, show_floating_labels_button_, turn_dialog_button_,
 	            turn_bell_button_, show_team_colours_button_, show_colour_cursors_button_,
 	            show_haloing_button_, video_mode_button_, hotkeys_button_, gamma_button_,
-				flip_time_button_, advanced_button_;
+				flip_time_button_, advanced_button_, sound_button_, music_button_;
 	gui::label music_label_, sound_label_, scroll_label_, gamma_label_;
 	unsigned slider_label_width_;
 
@@ -857,6 +898,8 @@ preferences_dialog::preferences_dialog(display& disp, const config& game_cfg)
 	  hotkeys_button_(disp.video(), _("Hotkeys")),
 	  gamma_button_(disp.video(), _("Adjust Gamma"), gui::button::TYPE_CHECK),
 	  flip_time_button_(disp.video(), _("Reverse Time Graphics"), gui::button::TYPE_CHECK),
+	  sound_button_(disp.video(), _("Sound effects"), gui::button::TYPE_CHECK),
+	  music_button_(disp.video(), _("Music"), gui::button::TYPE_CHECK),
 	  advanced_button_(disp.video(), "", gui::button::TYPE_CHECK),
 	  music_label_(disp.video(), _("Music Volume:")), sound_label_(disp.video(), _("SFX Volume:")),
 	  scroll_label_(disp.video(), _("Scroll Speed:")), gamma_label_(disp.video(), _("Gamma:")),
@@ -870,21 +913,22 @@ preferences_dialog::preferences_dialog(display& disp, const config& game_cfg)
 	set_measurements(400, 400);
 #endif
 
-	slider_label_width_ = maximum<unsigned>(music_label_.width(),
-	                      maximum<unsigned>(sound_label_.width(),
-	                      maximum<unsigned>(scroll_label_.width(),
-	                                        gamma_label_.width())));
 
-	sound_slider_.set_min(1);
-	sound_slider_.set_max(100);
+	sound_button_.set_check(sound_on());
+	sound_button_.set_help_string(_("Sound effects on/off"));
+	sound_slider_.set_min(0);
+	sound_slider_.set_max(128);
 	sound_slider_.set_value(sound_volume());
 	sound_slider_.set_help_string(_("Change the sound effects volume"));
 
-	music_slider_.set_min(1);
-	music_slider_.set_max(100);
+	music_button_.set_check(music_on());
+	music_button_.set_help_string(_("Music on/off"));
+	music_slider_.set_min(0);
+	music_slider_.set_max(128);
 	music_slider_.set_value(music_volume());
 	music_slider_.set_help_string(_("Change the music volume"));
 
+
 	scroll_slider_.set_min(1);
 	scroll_slider_.set_max(100);
 	scroll_slider_.set_value(scroll_speed());
@@ -952,8 +996,8 @@ void preferences_dialog::update_location(SDL_Rect const &rect)
 	// General tab
 	int ypos = rect.y;
 	scroll_label_.set_location(rect.x, ypos);
-	SDL_Rect scroll_rect = { rect.x + slider_label_width_, ypos,
-	                         rect.w - slider_label_width_ - border, 0 };
+	SDL_Rect scroll_rect = { rect.x + scroll_label_.width(), ypos,
+	                         rect.w - scroll_label_.width() - border, 0 };
 	scroll_slider_.set_location(scroll_rect);
 	ypos += item_interline; turbo_button_.set_location(rect.x, ypos);
 	ypos += item_interline; show_ai_moves_button_.set_location(rect.x, ypos);
@@ -968,8 +1012,8 @@ void preferences_dialog::update_location(SDL_Rect const &rect)
 	gamma_button_.set_location(rect.x, ypos);
 	ypos += item_interline;
 	gamma_label_.set_location(rect.x, ypos);
-	SDL_Rect gamma_rect = { rect.x + slider_label_width_, ypos,
-	                        rect.w - slider_label_width_ - border, 0 };
+	SDL_Rect gamma_rect = { rect.x + gamma_label_.width(), ypos,
+	                        rect.w - gamma_label_.width() - border, 0 };
 	gamma_slider_.set_location(gamma_rect);
 	ypos += item_interline; flip_time_button_.set_location(rect.x,ypos);
 	ypos += item_interline; show_floating_labels_button_.set_location(rect.x, ypos);
@@ -979,17 +1023,25 @@ void preferences_dialog::update_location(SDL_Rect const &rect)
 	ypos += item_interline; video_mode_button_.set_location(rect.x, ypos);
 
 	// Sound tab
+	slider_label_width_ = maximum<unsigned>(music_label_.width(), sound_label_.width());
 	ypos = rect.y;
-	music_label_.set_location(rect.x, ypos);
-	SDL_Rect music_rect = { rect.x + slider_label_width_, ypos,
-	                        rect.w - slider_label_width_ - border, 0 };
-	music_slider_.set_location(music_rect);
+	sound_button_.set_location(rect.x, ypos);
+
 	ypos += item_interline;
 	sound_label_.set_location(rect.x, ypos);
-	SDL_Rect sound_rect = { rect.x + slider_label_width_, ypos,
-				rect.w - slider_label_width_ - border, 0 };
+	const SDL_Rect sound_rect = { rect.x + slider_label_width_, ypos,
+	                        rect.w - slider_label_width_ - border, 0 };
 	sound_slider_.set_location(sound_rect);
 
+	ypos += item_interline;
+	music_button_.set_location(rect.x, ypos);
+
+	ypos += item_interline;
+	music_label_.set_location(rect.x, ypos);
+	const SDL_Rect music_rect = { rect.x + slider_label_width_, ypos,
+	                        rect.w - slider_label_width_ - border, 0 };
+	music_slider_.set_location(music_rect);
+
 	//Advanced tab
 	ypos = rect.y;
 	advanced_.set_location(rect.x,ypos);
@@ -1036,10 +1088,22 @@ void preferences_dialog::process_event()
 		gamma_slider_.hide(hide_gamma);
 		gamma_label_.hide(hide_gamma);
 	}
+
+	if (sound_button_.pressed()) {
+		if(!set_sound(sound_button_.checked()))
+			sound_button_.set_check(false);
+	}
+	set_sound_volume(sound_slider_.value());
+
+	if (music_button_.pressed()) {
+		if(!set_music(music_button_.checked()))
+			music_button_.set_check(false);
+	}
+	set_music_volume(music_slider_.value());
+
 	if (flip_time_button_.pressed())
 		set_flip_time(flip_time_button_.checked());
-	set_sound_volume(sound_slider_.value());
-	set_music_volume(music_slider_.value());
+
 	set_scroll_speed(scroll_slider_.value());
 	set_gamma(gamma_slider_.value());
 
@@ -1132,8 +1196,10 @@ void preferences_dialog::set_selection(int index)
 	flip_time_button_.hide(hide_display);
 
 	const bool hide_sound = tab_ != SOUND_TAB;
+	music_button_.hide(hide_sound);
 	music_label_.hide(hide_sound);
 	music_slider_.hide(hide_sound);
+	sound_button_.hide(hide_sound);
 	sound_label_.hide(hide_sound);
 	sound_slider_.hide(hide_sound);
 
