@@ -1,6 +1,6 @@
-/* $Id: preferences.hpp,v 1.56 2005/06/04 19:16:05 ott Exp $ */
+/* $Id: preferences.hpp 7648 2005-07-31 20:22:08Z j_daniel $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -55,12 +55,20 @@ namespace preferences {
 	const std::string& language();
 	void set_language(const std::string& s);
 
-	int music_volume();
-	void set_music_volume(int vol);
+	// don't rename it to sound() because of a gcc-3.3 branch bug
+	// which will cause it to conflict with the sound namespace
+	bool sound_on();
+	bool set_sound(bool ison);
 
 	int sound_volume();
 	void set_sound_volume(int vol);
 
+	bool music_on();
+	bool set_music(bool ison);
+
+	int music_volume();
+	void set_music_volume(int vol);
+
 	void mute(bool muted);
 	bool is_muted();
 
@@ -104,6 +112,9 @@ namespace preferences {
 	bool allow_observers();
 	void set_allow_observers(bool value);
 
+	bool use_map_settings();
+	void set_use_map_settings(bool value);
+
 	bool fog();
 	void set_fog(bool value);
 
