@@ -1,3 +1,16 @@
+/* $Id: reports.cpp 7960 2005-08-21 20:58:48Z gruikya $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #include "global.hpp"
 
 #include "actions.hpp"
@@ -190,12 +203,11 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 		const std::vector<attack_type>& attacks = u->second.attacks();
 		for(std::vector<attack_type>::const_iterator at_it = attacks.begin();
 		    at_it != attacks.end(); ++at_it) {
-			const std::string& lang_weapon = gettext(at_it->name().c_str());
 			const std::string& lang_type = gettext(at_it->type().c_str());
 
-			str << lang_weapon << " (" << lang_type << ")\n";
+			str << at_it->name() << " (" << lang_type << ")\n";
 
-			tooltip << lang_weapon << " (" << lang_type << ")\n";
+			tooltip << at_it->name() << " (" << lang_type << ")\n";
 
 			//find all the unit types on the map, and show this weapon's bonus against all the different units
 			std::set<std::string> seen_units;
@@ -403,15 +415,15 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 		}
 	}
 	case REPORT_CLOCK: {
-	  time_t t=time(NULL);
-	  struct tm *lt=localtime(&t);
-	  char temp[10];
-	  size_t s=strftime(temp,10,preferences::clock_format().c_str(),lt);
-	  if(s>0){
-	    return report(temp);
-	  }else{
-	    return report();
-	  }
+		time_t t = time(NULL);
+		struct tm *lt=localtime(&t);
+		char temp[10];
+		size_t s = strftime(temp,10,preferences::clock_format().c_str(),lt);
+		if(s>0) {
+			return report(temp);
+		} else {
+			return report();
+		}
 	}
 
 	default:
