@@ -1,6 +1,6 @@
-/* $Id: parser.cpp,v 1.19 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: parser.cpp 8216 2005-09-12 21:37:41Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Copyright (C) 2005 by Philippe Plantier <ayin@anathas.org>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -280,7 +280,7 @@ void parser::parse_variable()
 std::string parser::lineno_string(utils::string_map &i18n_symbols, std::string const &lineno,
 			          std::string const &error_string)
 {
-	std::vector< std::string > pos = utils::split(lineno, ' ');
+	std::vector< std::string > pos = utils::quoted_split(lineno, ' ');
 	std::vector< std::string >::const_iterator i = pos.begin(), end = pos.end();
 	std::string included_from = _(" included from ");
 	std::string res;
