@@ -1,6 +1,6 @@
-/* $Id: preprocessor.cpp,v 1.21 2005/06/23 23:10:54 Sirp Exp $ */
+/* $Id: preprocessor.cpp 8214 2005-09-12 21:33:34Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
@@ -87,13 +87,10 @@ preprocessor_streambuf::preprocessor_streambuf(preproc_map *def)
 	: current_(NULL), defines_(def), textdomain_(PACKAGE),
 	  depth_(0), quoted_(false)
 {
-	if(defines_ == NULL) {
-		defines_ = &default_defines_;
-	}
 }
 
 preprocessor_streambuf::preprocessor_streambuf(preprocessor_streambuf const &t)
-	: current_(NULL), defines_(t.defines_),
+	: std::streambuf(), current_(NULL), defines_(t.defines_),
 	  textdomain_(PACKAGE), depth_(t.depth_), quoted_(t.quoted_)
 {
 }
@@ -190,6 +187,7 @@ class preprocessor_data: preprocessor
 	void put(std::string const &);
 public:
 	preprocessor_data(preprocessor_streambuf &, std::istream *,
+	                  std::string const &history,  
 	                  std::string const &name, int line,
 	                  std::string const &dir, std::string const &domain);
 	virtual bool get_chunk();
@@ -201,7 +199,7 @@ preprocessor_file::preprocessor_file(preprocessor_streambuf &t, std::string cons
 	if (is_directory(name))
 		get_files_in_dir(name, &files_, NULL, ENTIRE_FILE_PATH);
 	else
-		new preprocessor_data(t, istream_file(name), name, 1, directory_name(name), t.textdomain_);
+		new preprocessor_data(t, istream_file(name), "", name, 1, directory_name(name), t.textdomain_);
 	pos_ = files_.begin();
 	end_ = files_.end();
 }
@@ -220,12 +218,20 @@ bool preprocessor_file::get_chunk()
 }
 
 preprocessor_data::preprocessor_data(preprocessor_streambuf &t, std::istream *i,
+                                     std::string const &history,
                                      std::string const &name, int linenum,
                                      std::string const &directory, std::string const &domain)
 	: preprocessor(t), in_(i), directory_(directory), slowpath_(0), skipping_(0), linenum_(linenum)
 {
 	std::ostringstream s;
-	s << name;
+
+	s << history;
+	if (!name.empty()) {
+		std::string ename(name);
+		if (!history.empty())
+			s << ' ';
+		s << utils::escape(ename, " \\");
+	}
 	if (!t.location_.empty())
 		s << ' ' << t.linenum_ << ' ' << t.location_;
 	t.location_ = s.str();
@@ -282,8 +288,10 @@ std::string preprocessor_data::read_word()
 	std::string res;
 	for(;;) {
 		int c = in_->peek();
-		if (!in_->good() || utils::portable_isspace(c))
+		if (c == preprocessor_streambuf::traits_type::eof() || utils::portable_isspace(c)) {
+			// LOG_CF << "(" << res << ")\n";
 			return res;
+		}
 		in_->get();
 		res += (char)c;
 	}
@@ -455,7 +463,7 @@ bool preprocessor_data::get_chunk()
 				target_.defines_->insert(std::make_pair(
 					symbol, preproc_define(buffer, items, target_.textdomain_,
 					                       linenum + 1, target_.location_)));
-				LOG_CF << "defining macro " << symbol << '\n';
+				LOG_CF << "defining macro " << symbol << " (location " << target_.location_ << ")\n";
 			}
 		} else if (command == "ifdef") {
 			skip_spaces();
@@ -617,7 +625,7 @@ bool preprocessor_data::get_chunk()
 				std::string const &dir = directory_name(val.location.substr(0, val.location.find(' ')));
 				if (!slowpath_) {
 					LOG_CF << "substituting macro " << symbol << '\n';
-					new preprocessor_data(target_, buffer, val.location,
+					new preprocessor_data(target_, buffer, val.location, "", 
 					                      val.linenum, dir, val.textdomain);
 				} else {
 					LOG_CF << "substituting (slow) macro " << symbol << '\n';
@@ -625,7 +633,7 @@ bool preprocessor_data::get_chunk()
 					preprocessor_streambuf *buf =
 						new preprocessor_streambuf(target_);
 					{	std::istream in(buf);
-						new preprocessor_data(*buf, buffer, val.location,
+						new preprocessor_data(*buf, buffer, val.location, "",
 						                      val.linenum, dir, val.textdomain);
 						res << in.rdbuf(); }
 					delete buf;
@@ -714,15 +722,36 @@ bool preprocessor_data::get_chunk()
 struct preprocessor_deleter: std::basic_istream<char>
 {
 	preprocessor_streambuf *buf_;
-	preprocessor_deleter(preprocessor_streambuf *buf) : std::basic_istream<char>(buf), buf_(buf) {}
-	~preprocessor_deleter() { rdbuf(NULL); delete buf_; }
+	preproc_map *defines_;
+	preprocessor_deleter(preprocessor_streambuf *buf, preproc_map *defines);
+	~preprocessor_deleter();
 };
 
+preprocessor_deleter::preprocessor_deleter(preprocessor_streambuf *buf, preproc_map *defines)
+	: std::basic_istream<char>(buf), buf_(buf), defines_(defines)
+{
+}
+
+preprocessor_deleter::~preprocessor_deleter()
+{
+	rdbuf(NULL);
+	delete buf_;
+	delete defines_;
+}
+
+
 std::istream *preprocess_file(std::string const &fname,
                               preproc_map *defines)
 {
 	log_scope("preprocessing file...");
+	preproc_map *owned_defines = NULL;
+	if (!defines) {
+		// if no preproc_map has been given, create a new one, and ensure
+		// it is destroyed when the stream is by giving it to the deleter
+		owned_defines = new preproc_map;
+		defines = owned_defines;
+	}
 	preprocessor_streambuf *buf = new preprocessor_streambuf(defines);
 	new preprocessor_file(*buf, fname);
-	return new preprocessor_deleter(buf);
+	return new preprocessor_deleter(buf, owned_defines);
 }
