@@ -1,6 +1,6 @@
-/* $Id: string_utils.hpp,v 1.14 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: string_utils.hpp 8214 2005-09-12 21:33:34Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Copyright (C) 2005 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
@@ -21,7 +21,7 @@
 
 #include "SDL_types.h"
 #include "tstring.hpp"
-
+#include "util.hpp"
 
 class variable_set
 {
@@ -54,6 +54,7 @@ std::vector< std::string > quoted_split(std::string const &val, char c= ',',
                                         int flags = REMOVE_EMPTY | STRIP_SPACES, char quote = '\\');
 std::pair< int, int > parse_range(std::string const &str);
 bool notspace(char c);
+std::string &escape(std::string &str, const std::string& special_chars);
 std::string &escape(std::string &str);
 std::string &unescape(std::string &str);
 std::string &strip(std::string &str);
