@@ -1,3 +1,16 @@
+/* $Id: game.cpp 7813 2005-08-08 22:59:19Z isaaccp $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #include "../global.hpp"
 
 #include "game.hpp"
@@ -97,6 +110,13 @@ void game::start_game()
 {
 	started_ = true;
 
+	//set all side controllers to 'human' so that observers will understand that they can't
+	//take control of any sides if they happen to have the same name as one of the descriptions
+	config::child_itors sides = level_.child_range("side");
+	for(; sides.first != sides.second; ++sides.first) {
+		(**sides.first)["controller"] = "human";
+	}
+
 	describe_slots();
 	if(description()) {
 		description()->values["turn"] = describe_turns(1,level()["turns"]);
@@ -117,21 +137,21 @@ void game::start_game()
 bool game::take_side(network::connection player, const config& cfg)
 {
 	wassert(is_member(player));
-	
+
 	// verify that side is a side id
 	const std::string& side = cfg["side"];
-	ssize_t side_num;
+	size_t side_num;
 	try {
-		side_num = lexical_cast<ssize_t, std::string>(side);
+		side_num = lexical_cast<size_t, std::string>(side);
 		if(side_num < 1 || side_num > 9)
 			return false;
 	}
 	catch(bad_lexical_cast& bad_lexical) {
 		return false;
 	}
-	
+
 	size_t side_index = static_cast<size_t>(side_num - 1);
-	
+
 	//if the side is already taken, see if we can give the player
 	//another side instead
 	if(side_controllers_[side_index] == "human" || (sides_taken_[side_index] && side_controllers_[side_index] == "network")) {
@@ -140,7 +160,7 @@ bool game::take_side(network::connection player, const config& cfg)
 			if((**i)["controller"] == "network") {
 				// don't allow players to take sides in games with invalid side numbers
 				try {
-					side_num = lexical_cast<ssize_t, std::string>((**i)["side"]);
+					side_num = lexical_cast<size_t, std::string>((**i)["side"]);
 					if(side_num < 1 || side_num > 9)
 						return false;
 				}
@@ -191,12 +211,12 @@ void game::update_side_data()
 			continue;
 		}
 
-		ssize_t side_num;
+		size_t side_num;
 		size_t side_index;
 		config::child_iterator sd;
 		for(sd = level_sides.first; sd != level_sides.second; ++sd) {
 			try {
-				side_num = lexical_cast<ssize_t, std::string>((**sd)["side"]);
+				side_num = lexical_cast<size_t, std::string>((**sd)["side"]);
 				if(side_num < 1 || side_num > 9)
 					continue;
 			}
@@ -204,7 +224,7 @@ void game::update_side_data()
 				continue;
 			}
 			side_index = static_cast<size_t>(side_num - 1);
-			
+
 			if((**sd)["controller"] == "network") {
 				side_controllers_[side_index] = "network";
 				if((**sd)["user_description"] == info->second.name()) {
@@ -220,6 +240,7 @@ void game::update_side_data()
 				sides_taken_[side_index] = true;
 			}
 			else if((**sd)["controller"] == "human") {
+				sides_.insert(std::pair<network::connection,size_t>(players_.front(),side_index));
 				sides_taken_[side_index] = true;
 				side_controllers_[side_index] = "human";
 			}
@@ -245,9 +266,9 @@ const std::string& game::transfer_side_control(const config& cfg)
 	}
 	const std::string& side = cfg["side"];
 	static const std::string invalid = "Invalid side number";
-	ssize_t side_num;
+	size_t side_num;
 	try {
-		side_num = lexical_cast<ssize_t, std::string>(side);
+		side_num = lexical_cast<size_t, std::string>(side);
 		if(side_num < 1 || side_num > 9)
 			return invalid;
 	}
@@ -257,9 +278,9 @@ const std::string& game::transfer_side_control(const config& cfg)
 	const size_t nsides = level_.get_children("side").size();
 	if(side_num > nsides)
 		return invalid;
-	
+
 	const size_t side_index = static_cast<size_t>(side_num - 1);
-	
+
 	if(side_controllers_[side_index] == "network" && sides_taken_[side_index]) {
 		static const std::string already = "This side is already controlled by a player";
 		return already;
@@ -276,7 +297,7 @@ const std::string& game::transfer_side_control(const config& cfg)
 	side_controllers_[side_index] = "network";
 	sides_taken_[side_index] = true;
 	sides_.insert(std::pair<const network::connection,size_t>(*i, side_index));
-	
+
 	// send a response to the host and to the new controller
 	config response;
 	config& change = response.add_child("change_controller");
@@ -452,7 +473,7 @@ void game::remove_player(network::connection player, bool notify_creator)
 {
 	const std::vector<network::connection>::iterator itor =
 	             std::find(players_.begin(),players_.end(),player);
-	
+
 	if(itor != players_.end())
 		players_.erase(itor);
 
@@ -472,7 +493,7 @@ void game::remove_player(network::connection player, bool notify_creator)
 	}
 	if(!observer)
 		sides_.erase(player);
-	
+
 	send_user_list();
 
 	const player_map::const_iterator pl = player_info_->find(player);
