@@ -1,6 +1,6 @@
-/* $Id: show_dialog.cpp,v 1.134 2005/06/19 13:32:13 Sirp Exp $ */
+/* $Id: show_dialog.cpp 7946 2005-08-21 14:16:30Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -669,9 +669,7 @@ int show_dialog(display& disp, surface image,
 
 	CKey key;
 
-	bool left_button = true, right_button = true, key_down = true,
-	     up_arrow = false, down_arrow = false,
-	     page_up = false, page_down = false;
+	bool left_button = true, right_button = true, key_down = true;
 
 	disp.invalidate_all();
 
@@ -693,12 +691,6 @@ int show_dialog(display& disp, surface image,
 		const bool new_key_down = key[SDLK_SPACE] || key[SDLK_RETURN] ||
 		                          key[SDLK_ESCAPE];
 
-		const bool new_up_arrow = key[SDLK_UP] != 0;
-		const bool new_down_arrow = key[SDLK_DOWN] != 0;
-
-		const bool new_page_up = key[SDLK_PAGEUP] != 0;
-		const bool new_page_down = key[SDLK_PAGEDOWN] != 0;
-
 		if((!key_down && key[SDLK_RETURN] || menu_.double_clicked()) &&
 		   (type == YES_NO || type == OK_CANCEL || type == OK_ONLY || type == CLOSE_ONLY)) {
 
@@ -755,11 +747,6 @@ int show_dialog(display& disp, surface image,
 			}
 		}
 
-		up_arrow = new_up_arrow;
-		down_arrow = new_down_arrow;
-		page_up = new_page_up;
-		page_down = new_page_down;
-
 		events::raise_process_event();
 		events::raise_draw_event();
 
@@ -870,18 +857,17 @@ network::connection network_data_dialog(display& disp, const std::string& msg, c
 	events::raise_draw_event();
 	disp.flip();
 
-	std::pair<int,int> old_stats = network::current_transfer_stats();
+	network::statistics old_stats = network::get_receive_stats(connection_num);
 
 	cfg.clear();
 	for(;;) {
 		const network::connection res = network::receive_data(cfg,connection_num,100);
-
-		const std::pair<int,int> stats = network::current_transfer_stats();
-		if(stats.first != -1 && stats.second != 0 && stats != old_stats) {
+		const network::statistics stats = network::get_receive_stats(connection_num);
+		if(stats.current_max != 0 && stats != old_stats) {
 			old_stats = stats;
-			progress.set_progress_percent((stats.first*100)/stats.second);
+			progress.set_progress_percent((stats.current*100)/stats.current_max);
 			std::ostringstream stream;
-			stream << stats.first/1024 << "/" << stats.second/1024 << _("KB");
+			stream << stats.current/1024 << "/" << stats.current_max/1024 << _("KB");
 			progress.set_text(stream.str());
 		}
 
