@@ -1,6 +1,6 @@
-/* $Id: team.cpp,v 1.90 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: team.cpp 8302 2005-09-18 23:32:23Z Sirp $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -202,6 +202,7 @@ void team::team_info::write(config& cfg) const
 	for(std::vector<config>::const_iterator ai = ai_params.begin(); ai != ai_params.end(); ++ai) {
 		cfg.add_child("ai",*ai);
 	}
+	cfg["ai_algorithm"] = ai_algorithm;
 
 	cfg["gold"] = gold;
 	cfg["income"] = income;
@@ -233,7 +234,6 @@ void team::team_info::write(config& cfg) const
 	case EMPTY: cfg["controller"] = "null"; break;
 	default: wassert(false);
 	}
-
 	cfg["persistent"] = persistent ? "1" : "0";
 
 	sprintf(buf,"%d",villages_per_scout);
@@ -316,10 +316,10 @@ void team::write(config& cfg) const
 	cfg["shroud_data"] = shroud_.write();
 }
 
-void team::get_village(const gamemap::location& loc)
+bool team::get_village(const gamemap::location& loc)
 {
 	villages_.insert(loc);
-	game_events::fire("capture",loc);
+	return game_events::fire("capture",loc);
 }
 
 void team::lose_village(const gamemap::location& loc)
