@@ -1,6 +1,6 @@
-/* $Id: terrain.cpp,v 1.29 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: terrain.cpp 7490 2005-07-16 18:51:56Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -77,6 +77,11 @@ char terrain_type::letter() const
 	return letter_;
 }
 
+bool terrain_type::is_nonnull() const
+{
+	return (letter_ != 0) && (letter_ != ' ');
+}
+
 const std::string& terrain_type::type() const
 {
 	return type_;
