@@ -1,3 +1,16 @@
+/* $Id: thread.hpp 8172 2005-09-06 13:53:14Z ott $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #ifndef THREAD_HPP_INCLUDED
 #define THREAD_HPP_INCLUDED
 
@@ -148,18 +161,14 @@ public:
 	// signal the condition and wake up one thread waiting on the
 	// condition. If no thread is waiting, notify_one() is a no-op.
 	// Does not unlock the mutex.
-	//
-	// \todo SDL_CondSignal can return an error. This is never checked
-	void notify_one();
+	bool notify_one();
 
 	// signal all threads waiting on the condition and let them contend
 	// for the lock. This is often used when varying resource amounts are
 	// involved and you do not know how many processes might continue.
 	// The function should be used with care, especially if many threads are
 	// waiting on the condition variable.
-	//
-	// \todo SDL_CondBroadcast can return an error. This is never checked
-	void notify_all();
+	bool notify_all();
 
 private:
 	condition(const condition&);
@@ -192,7 +201,7 @@ public:
 
 	enum RESULT { COMPLETED, ABORTED };
 
-	async_operation() : aborted_(false) {}
+	async_operation() : aborted_(false), finishedVar_(false) {}
 	virtual ~async_operation() {}
 
 	RESULT execute(waiter& wait);
@@ -205,7 +214,7 @@ public:
 	//while holding the mutex and after checking is_aborted()
 	//if we want to be sure that if the operation is completed, the caller is notified.
 	//will be called in any case after the operation returns
-	void notify_finished();
+	bool notify_finished();
 
 	//must hold the mutex before calling this function from the worker thread
 	bool is_aborted() const { return aborted_; }
@@ -213,6 +222,7 @@ public:
 private:
 	bool aborted_;
 	condition finished_;
+	bool finishedVar_;
 	mutex mutex_;
 };
 
