@@ -1,6 +1,6 @@
-/* $Id: unit.cpp,v 1.154 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: unit.cpp 7953 2005-08-21 17:46:03Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -119,7 +119,7 @@ unit::unit(const unit_type* t, const unit& u) :
 	gender_(u.gender_), variation_(u.variation_),
 	type_(&t->get_gender_unit_type(u.gender_).get_variation(u.variation_)),
 	state_(STATE_NORMAL),
-	hitpoints_(type_->hitpoints()),
+	hitpoints_(u.hitpoints()),
 	maxHitpoints_(type_->hitpoints()),
 	backupMaxHitpoints_(type_->hitpoints()),
 	experience_(0),
@@ -144,7 +144,9 @@ unit::unit(const unit_type* t, const unit& u) :
 
 	//apply modifications etc, refresh the unit
 	apply_modifications();
-	heal_all();
+	if(u.type().id()!=t->id()){
+	  heal_all();
+	}
 	statusFlags_.clear();
 }
 
@@ -257,7 +259,7 @@ int unit::movement_left() const
 
 bool unit::can_attack() const
 {
-	return moves_ != -1;
+	return moves_ != ATTACKED;
 }
 
 void unit::set_movement(int moves)
@@ -485,6 +487,16 @@ bool unit::incapacitated() const
 	return stone();
 }
 
+bool unit::has_moved() const
+{
+	return this->movement_left() != this->total_movement();
+}
+
+bool unit::has_goto() const
+{
+        return this->get_goto().valid();
+}
+
 bool unit::emits_zoc() const
 {
 	return type().has_zoc() && stone() == false;
@@ -568,7 +580,7 @@ bool unit::matches_filter(const config& cfg) const
 		const std::vector<attack_type>& attacks = this->attacks();
 		for(std::vector<attack_type>::const_iterator i = attacks.begin();
 		    i != attacks.end(); ++i) {
-			if(i->name() == weapon) {
+			if(i->id() == weapon) {
 				has_weapon = true;
 			}
 		}
