@@ -1,6 +1,6 @@
-/* $Id: unit.hpp,v 1.70 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: unit.hpp 7851 2005-08-11 14:42:36Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -90,6 +90,8 @@ public:
 	bool stone() const;
 
 	bool incapacitated() const;
+	bool has_moved() const;
+	bool has_goto() const;
 
 	bool emits_zoc() const;
 
@@ -161,6 +163,10 @@ public:
 	bool move_interrupted() const;
 	const gamemap::location& get_interrupted_move() const;
 	void set_interrupted_move(const gamemap::location& interrupted_move);
+	//is set to the number of moves left, ATTACKED if attacked,
+	// MOVED if moved and then pressed "end turn"
+	// NOT_MOVED if not moved and pressed "end turn"
+	enum MOVES { ATTACKED=-1, MOVED=-2, NOT_MOVED=-3 };
 private:
 	unit_race::GENDER generate_gender(const unit_type& type, bool use_genders);
 	unit_race::GENDER gender_;
@@ -182,10 +188,6 @@ private:
 
 	int side_;
 
-	//is set to the number of moves left, ATTACKED if attacked,
-	// MOVED if moved and then pressed "end turn"
-	// NOT_MOVED if not moved and pressed "end turn"
-	enum MOVES { ATTACKED=-1, MOVED=-2, NOT_MOVED=-3 };
 	int moves_;
 	bool user_end_turn_;
 	bool facingLeft_;
