@@ -1,6 +1,6 @@
-/* $Id: unit_types.hpp,v 1.70 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: unit_types.hpp 7953 2005-08-21 17:46:03Z gruikya $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -79,7 +79,8 @@ public:
 	enum RANGE { SHORT_RANGE, LONG_RANGE };
 
 	attack_type(const config& cfg);
-	const std::string& name() const;
+	const t_string& name() const;
+	const std::string& id() const;
 	const std::string& type() const;
 	const std::string& special() const;
 	const std::string& icon() const;
@@ -102,7 +103,8 @@ public:
 private:
 	std::vector<unit_animation> animation_;
 	std::vector<unit_animation> direction_animation_[6];
-	std::string name_;
+	t_string description_;
+	std::string id_;
 	std::string type_;
 	std::string special_;
 	std::string icon_;
