@@ -1,3 +1,16 @@
+/* $Id: menu.cpp 8173 2005-09-06 14:00:05Z ott $ */
+/*
+   Copyright (C) 2003-5 by David White <davidnwhite@verizon.net>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY.
+
+   See the COPYING file for more details.
+*/
+
 #include "../global.hpp"
 
 #include "menu.hpp"
@@ -393,13 +406,16 @@ void menu::set_items(const std::vector<std::string>& items, bool strip_spaces, b
 	set_dirty();
 }
 
-void menu::set_max_height(const int new_max_height) {
+void menu::set_max_height(const int new_max_height)
+{
 	max_height_ = new_max_height;
 	itemRects_.clear();
 	max_items_ = -1;
+	update_size();
 }
 
-void menu::set_max_width(const int new_max_width) {
+void menu::set_max_width(const int new_max_width)
+{
 	max_width_ = new_max_width;
 }
 
@@ -510,10 +526,13 @@ void menu::handle_event(const SDL_Event& event)
 {
 	scrollarea::handle_event(event);
 	if(event.type == SDL_KEYDOWN) {
-		key_press(event.key.keysym.sym);
+		// Only pass key events if we have the focus
+		if (focus())
+			key_press(event.key.keysym.sym);
 	} else if(event.type == SDL_MOUSEBUTTONDOWN &&
 	          event.button.button == SDL_BUTTON_LEFT ||
 		  event.type == DOUBLE_CLICK_EVENT) {
+
 		int x = 0;
 		int y = 0;
 		if(event.type == SDL_MOUSEBUTTONDOWN) {
@@ -526,6 +545,7 @@ void menu::handle_event(const SDL_Event& event)
 
 		const int item = hit(x,y);
 		if(item != -1) {
+			set_focus(true);
 			move_selection(item);
 
 			if(click_selects_) {
