@@ -1,4 +1,4 @@
-/* $Id: scrollarea.cpp,v 1.12 2005/03/18 21:21:48 ydirson Exp $*/
+/* $Id: scrollarea.cpp 8173 2005-09-06 14:00:05Z ott $*/
 /*
    Copyright (C) 2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -22,13 +22,15 @@ namespace gui {
 
 scrollarea::scrollarea(CVideo &video)
 	: widget(video), scrollbar_(video),
-	  old_position_(0), recursive_(false), shown_scrollbar_(false)
+	  old_position_(0), recursive_(false), shown_scrollbar_(false),
+	  shown_size_(0), full_size_(0)
 {
+	scrollbar_.hide(true);
 }
 
 bool scrollarea::has_scrollbar() const
 {
-	return scrollbar_.grip_height_ < scrollbar_.full_height_ && scrollbar_.is_valid_height(location().h);
+	return shown_size_ < full_size_ && scrollbar_.is_valid_height(location().h);
 }
 
 void scrollarea::update_location(SDL_Rect const &rect)
@@ -43,6 +45,7 @@ void scrollarea::update_location(SDL_Rect const &rect)
 		r.x -= w;
 		r.w = w;
 	}
+
 	if (!hidden())
 		scrollbar_.hide(!shown_scrollbar_);
 	set_inner_location(r);
@@ -64,7 +67,7 @@ void scrollarea::test_scrollbar()
 void scrollarea::hide(bool value)
 {
 	widget::hide(value);
-	if (has_scrollbar())
+	if (shown_scrollbar_)
 		scrollbar_.hide(value);
 }
 
@@ -96,12 +99,14 @@ void scrollarea::move_position(int dep)
 void scrollarea::set_shown_size(unsigned h)
 {
 	scrollbar_.set_shown_size(h);
+	shown_size_ = h;
 	test_scrollbar();
 }
 
 void scrollarea::set_full_size(unsigned h)
 {
 	scrollbar_.set_full_size(h);
+	full_size_ = h;
 	test_scrollbar();
 }
 
@@ -122,7 +127,7 @@ void scrollarea::process_event()
 SDL_Rect scrollarea::inner_location() const
 {
 	SDL_Rect r = location();
-	if (has_scrollbar())
+	if (shown_scrollbar_)
 		r.w -= scrollbar_.width();
 	return r;
 }
@@ -138,11 +143,14 @@ void scrollarea::handle_event(const SDL_Event& event)
 		return;
 
 	SDL_MouseButtonEvent const &e = event.button;
-	if (point_in_rect(e.x, e.y, inner_location()))
-		if (e.button == SDL_BUTTON_WHEELDOWN)
-			scrollbar_.move_position(scrollbar_.scroll_rate_);
-		else if (e.button == SDL_BUTTON_WHEELUP)
-			scrollbar_.move_position(-scrollbar_.scroll_rate_);
+	if (point_in_rect(e.x, e.y, inner_location())) {
+		if (e.button == SDL_BUTTON_WHEELDOWN) {
+			scrollbar_.scroll_down();
+		} else if (e.button == SDL_BUTTON_WHEELUP) {
+			scrollbar_.scroll_up();
+		}
+	}
 }
 
 }
+
