@@ -1,4 +1,4 @@
-/* $Id: scrollarea.hpp,v 1.6 2005/03/18 21:21:48 ydirson Exp $ */
+/* $Id: scrollarea.hpp 7943 2005-08-21 12:58:46Z gruikya $ */
 /*
    Copyright (C) 2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
@@ -55,6 +55,8 @@ private:
 	scrollbar scrollbar_;
 	int old_position_;
 	bool recursive_, shown_scrollbar_;
+	unsigned shown_size_;
+	unsigned full_size_;
 
 	void test_scrollbar();
 };
