@@ -1,6 +1,6 @@
-/* $Id: textbox.cpp,v 1.82 2005/06/04 19:16:06 ott Exp $ */
+/* $Id: textbox.cpp 8239 2005-09-14 20:57:32Z ott $ */
 /*
-   Copyright (C) 2003 by David White <davidnwhite@comcast.net>
+   Copyright (C) 2003 by David White <davidnwhite@verizon.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -231,6 +231,7 @@ void textbox::set_location(const SDL_Rect& rect)
 	text_pos_ = 0;
 
 	scrollarea::set_location(rect);
+	set_shown_size(location().h);
 }
 
 void textbox::scroll(int pos)
@@ -345,6 +346,16 @@ void textbox::erase_selection()
 	selstart_ = selend_ = -1;
 }
 
+namespace {
+	const unsigned int copypaste_modifier = 
+#ifdef __APPLE__
+		KMOD_LMETA | KMOD_RMETA
+#else
+		KMOD_CTRL
+#endif
+		;
+}
+
 void textbox::handle_event(const SDL_Event& event)
 {
 	scrollarea::handle_event(event);
@@ -437,6 +448,7 @@ void textbox::handle_event(const SDL_Event& event)
 	if(c == SDLK_RIGHT && cursor_ < text_.size())
 		++cursor_;
 
+	// ctrl-a, ctrl-e and ctrl-u are readline style shortcuts, even on Macs
 	if(c == SDLK_END || (c == SDLK_e && (modifiers & KMOD_CTRL)))
 		cursor_ = text_.size();
 
@@ -459,7 +471,7 @@ void textbox::handle_event(const SDL_Event& event)
 		}
 	}
 
-	if(c == SDLK_u && (modifiers & KMOD_CTRL)) {
+	if(c == SDLK_u && (modifiers & KMOD_CTRL)) { // clear line
 		changed = true;
 		cursor_ = 0;
 		text_.resize(0);
@@ -488,9 +500,9 @@ void textbox::handle_event(const SDL_Event& event)
 		if(character != 0)
 			LOG_STREAM(info, display) << "Char: " << character << ", c = " << c << "\n";
 
-		if(event.key.keysym.mod & KMOD_CTRL) {
+		if(event.key.keysym.mod & copypaste_modifier) {
 			switch(c) {
-			case SDLK_v:
+			case SDLK_v: // paste
 				{
 				changed = true;
 				if(is_selection())
@@ -515,7 +527,7 @@ void textbox::handle_event(const SDL_Event& event)
 
 				break;
 
-			case SDLK_c:
+			case SDLK_c: // copy
 				{
 				const size_t beg = minimum<size_t>(size_t(selstart_),size_t(selend_));
 				const size_t end = maximum<size_t>(size_t(selstart_),size_t(selend_));
